@@ -8,6 +8,8 @@
 
 import inspect
 import re
+import ctypes
+import ctypes.util
 from . import help as help_module
 from . import ui_utils
 from . import log
@@ -566,6 +568,10 @@ class ChildInfo(object):
         '''
         ret = []
         if self.completer is not None:
+            if sort_completion_inst is not None and sort_completion_inst.value == 0:
+                # Restore the original value of rl_sort_completion_matches
+                # before calling the completer again
+                sort_completion_inst.value = orig_sort_completion_value
             specs = inspect.getfullargspec(self.completer)
             if 'context' in specs.args:
                 ret = self.completer([self.name] + args, context)
@@ -591,3 +597,16 @@ def _check_args(fn, expected):
     if argnames != expected:
         raise ValueError(fn.__name__ +
                          ": Expected method with signature " + repr(expected))
+
+
+readline_path = ctypes.util.find_library('readline')
+sort_completion_inst = None
+if readline_path:
+    # Inspired by
+    # https://stackoverflow.com/questions/31229708/python-gnu-readline-bindings-keep-my-sort-order
+    # Python readline module sort the completion result by
+    # alphabetical order by default. To archive the custom
+    # sort order, need to disable the sort_completion_matches
+    rl = ctypes.cdll.LoadLibrary(readline_path)
+    sort_completion_inst = ctypes.c_ulong.in_dll(rl, 'rl_sort_completion_matches')
+    orig_sort_completion_value = sort_completion_inst.value
