@@ -50,23 +50,17 @@ def resources(args=None):
         return []
     nodes = xmlutil.get_interesting_nodes(cib_el, [])
     rsc_id_list = [x.get("id") for x in nodes if xmlutil.is_resource(x)]
-    if args and args[0] in ['promote', 'demote']:
-        return [item for item in rsc_id_list if xmlutil.RscState().is_ms_or_promotable_clone(item)]
-    if args and args[0] == "started":
-        return [item for item in rsc_id_list if xmlutil.RscState().is_running(item)]
-    if args and args[0] == "stopped":
-        return [item for item in rsc_id_list if not xmlutil.RscState().is_running(item)]
+    if args:
+        if args[0] in ('promote', 'demote'):
+            rsc_id_list = [item for item in rsc_id_list if xmlutil.RscState().is_ms_or_promotable_clone(item)]
+        elif args[0] == "start":
+            rsc_id_list = [item for item in rsc_id_list if not xmlutil.RscState().is_running(item)]
+        elif args[0] == "stop":
+            rsc_id_list = [item for item in rsc_id_list if xmlutil.RscState().is_running(item)]
+        rsc_id_list = [item for item in rsc_id_list if item not in args]
     return rsc_id_list
 
 
-def resources_started(args=None):
-    return resources(["started"])
-
-
-def resources_stopped(args=None):
-    return resources(["stopped"])
-
-
 def primitives(args):
     cib_el = xmlutil.resources_xml()
     if cib_el is None:
@@ -76,8 +70,8 @@ def primitives(args):
 
 
 nodes = call(xmlutil.listnodes)
-online_nodes = call(xmlutil.CrmMonXmlParser().get_node_list, "online")
-standby_nodes = call(xmlutil.CrmMonXmlParser().get_node_list, "standby")
+online_nodes = call(lambda x: xmlutil.CrmMonXmlParser().get_node_list(x), "online")
+standby_nodes = call(lambda x: xmlutil.CrmMonXmlParser().get_node_list(x), "standby")
 
 shadows = call(xmlutil.listshadows)
 
