@@ -39,16 +39,19 @@ def query_status(status_type):
     """
     Query status of corosync
 
-    Possible types could be ring/quorum/qdevice/qnetd
+    Possible types could be ring/quorum/qdevice/qnetd/cpg
     """
     status_func_dict = {
             "ring": query_ring_status,
             "quorum": query_quorum_status,
             "qdevice": query_qdevice_status,
-            "qnetd": query_qnetd_status
+            "qnetd": query_qnetd_status,
+            "cpg": query_cpg_status
             }
     if status_type in status_func_dict:
-        status_func_dict[status_type]()
+        out = sh.cluster_shell().get_stdout_or_raise_error("crm_node -l")
+        print(f"{out}\n")
+        print(status_func_dict[status_type]())
     else:
         raise ValueError("Wrong type \"{}\" to query status".format(status_type))
 
@@ -60,8 +63,7 @@ def query_ring_status():
     rc, out, err = ShellUtils().get_stdout_stderr("corosync-cfgtool -s")
     if rc != 0 and err:
         raise ValueError(err)
-    if out:
-        print(out)
+    return out
 
 
 def query_quorum_status():
@@ -69,14 +71,13 @@ def query_quorum_status():
     Query corosync quorum status
 
     """
-    utils.print_cluster_nodes()
     rc, out, err = ShellUtils().get_stdout_stderr("corosync-quorumtool -s")
     if rc != 0 and err:
         raise ValueError(err)
     # If the return code of corosync-quorumtool is 2,
     # that means no problem appeared but node is not quorate
     if rc in [0, 2] and out:
-        print(out)
+        return out
 
 
 def query_qdevice_status():
@@ -87,8 +88,7 @@ def query_qdevice_status():
         raise ValueError("QDevice/QNetd not configured!")
     cmd = "corosync-qdevice-tool -sv"
     out = sh.cluster_shell().get_stdout_or_raise_error(cmd)
-    utils.print_cluster_nodes()
-    print(out)
+    return out
 
 
 def query_qnetd_status():
@@ -105,18 +105,11 @@ def query_qnetd_status():
     if not qnetd_addr:
         raise ValueError("host for qnetd not configured!")
 
-    # Configure ssh passwordless to qnetd if detect password is needed
-    local_user, remote_user = utils.user_pair_for_ssh(qnetd_addr)
-    if utils.check_ssh_passwd_need(local_user, remote_user, qnetd_addr):
-        crmsh.bootstrap.configure_ssh_key(local_user)
-        utils.ssh_copy_id(local_user, remote_user, qnetd_addr)
-
     cmd = "corosync-qnetd-tool -lv -c {}".format(cluster_name)
     result = parallax.parallax_call([qnetd_addr], cmd)
     _, qnetd_result_stdout, _ = result[0][1]
     if qnetd_result_stdout:
-        utils.print_cluster_nodes()
-        print(utils.to_ascii(qnetd_result_stdout))
+        return utils.to_ascii(qnetd_result_stdout)
 
 
 def add_nodelist_from_cmaptool():
@@ -365,6 +358,14 @@ class Parser(object):
         return ''.join(joiner(self._tokens))
 
 
+def query_cpg_status():
+    """
+    Query corosync cpg status
+    """
+    cmd = "corosync-cpgtool -e"
+    return sh.cluster_shell().get_stdout_or_raise_error(cmd)
+
+
 def push_configuration(nodes):
     '''
     Push the local configuration to the list of remote nodes
