@@ -27,7 +27,8 @@ Help for the level itself is like this:
 
 import os
 import re
-from .utils import page_string, get_stdout_stderr
+from .sh import ShellUtils
+from .utils import page_string
 from . import config
 from . import clidisplay
 from .ordereddict import odict
@@ -79,6 +80,9 @@ class HelpEntry(object):
         self.long = long_help
         self.alias_for = alias_for
         self.generated = generated
+        self.from_cli = False
+        self.level = False
+        self.name = False
 
     def is_alias(self):
         return self.alias_for is not None
@@ -91,6 +95,11 @@ class HelpEntry(object):
         helpfilter = HelpFilter()
 
         short_help = clidisplay.help_header(self.short)
+        if self.from_cli and self.level and self.name:
+            level = '' if self.level == 'root' else self.level
+            _, output, _ = ShellUtils().get_stdout_stderr(f"crm {level} {self.name} --help-without-redirect")
+            page_string(short_help + '\n\n'+ output)
+            return
 
         long_help = self.long
         if long_help:
@@ -107,6 +116,11 @@ class HelpEntry(object):
     def set_long_help(self, long_help):
         self.long = long_help
 
+    def set_long_lazy_load_source(self, level, name, from_cli):
+        self.level = level
+        self.name = name
+        self.from_cli = from_cli
+
     def __str__(self):
         if self.long:
             return self.short + '\n' + self.long
@@ -347,10 +361,7 @@ def _load_help():
             lvl = entry['level']
             if lvl not in _COMMANDS:
                 _COMMANDS[lvl] = odict()
-            if entry['from_cli']:
-                _, help_output, _ = get_stdout_stderr("crm {} {} --help-without-redirect".format(lvl, name))
-                if help_output:
-                    helpobj.set_long_help(help_output.rstrip())
+            helpobj.set_long_lazy_load_source(entry['level'], entry['name'], entry['from_cli'])
             _COMMANDS[lvl][name] = helpobj
 
     def filter_line(line):
