@@ -11,7 +11,6 @@ from . import options
 from . import constants
 from . import clidisplay
 from . import term
-from . import upgradeutil
 from . import utils
 from . import userdir
 
@@ -345,10 +344,10 @@ def profile_run(context, user_args):
 
 def run():
     try:
+        envsetup()
         if len(sys.argv) >= 2 and sys.argv[1] == '--compgen':
             compgen()
             return 0
-        envsetup()
         userdir.mv_user_files()
 
         ui = ui_root.Root()
@@ -367,8 +366,10 @@ def run():
         if options.profile:
             return profile_run(context, user_args)
         else:
-            upgradeutil.upgrade_if_needed()
             return main_input_loop(context, user_args)
+    except utils.NoSSHError as msg:
+        logger.error('%s', msg)
+        sys.exit(1)
     except KeyboardInterrupt:
         if config.core.debug:
             raise
