@@ -377,7 +377,7 @@ class RAInfo(object):
         self.broken_ra = False
         return self.ra_elem
 
-    def params(self, completion=False):
+    def params(self):
         '''
         Construct a dict of dicts: parameters are keys and
         dictionary of attributes/values are values. Cached too.
@@ -385,12 +385,6 @@ class RAInfo(object):
         completion:
         If true, filter some (advanced) parameters out.
         '''
-        if completion:
-            if self.mk_ra_node() is None:
-                return None
-            return [c.get("name")
-                    for c in self.ra_elem.xpath("//parameters/parameter")
-                    if c.get("name") and c.get("name") not in self.excluded_from_completion]
         ident = "ra_params-%s" % self
         if cache.is_cached(ident):
             return cache.retrieve(ident)
@@ -399,7 +393,7 @@ class RAInfo(object):
         d = {}
         for c in self.ra_elem.xpath("//parameters/parameter"):
             name = c.get("name")
-            if not name:
+            if not name or name in self.excluded_from_completion:
                 continue
             required = c.get("required") if not (c.get("deprecated") or c.get("obsoletes")) else "0"
             unique = c.get("unique")
@@ -410,6 +404,10 @@ class RAInfo(object):
                 "type": typ,
                 "default": default,
             }
+        items = list(d.items())
+        # Sort the dictionary by required and then alphabetically
+        items.sort(key=lambda item: (item[1]["required"] != '1', item[0]))
+        d = dict(items)
         return cache.store(ident, d)
 
     def actions(self):
@@ -864,7 +862,10 @@ def disambiguate_ra_type(s):
     elif len(l) == 2:
         cl, tp = l
     else:
-        cl, tp = "ocf", l[0]
+        if l[0].startswith("fence_"):
+            cl, tp = "stonith", l[0]
+        else:
+            cl, tp = "ocf", l[0]
     pr = pick_provider(ra_providers(tp, cl)) if cl == 'ocf' else ''
     return cl, pr, tp
 
