@@ -3,7 +3,7 @@
 BIN_CRM = "/usr/sbin/crm"
 BIN_COLLECTOR = f"{BIN_CRM} report __collector"
 COMPRESS_DATA_FLAG = "COMPRESS CRM_REPORT DATA:::"
-LOG_PATTERNS = "CRIT: ERROR: error: warning: crit:"
+LOG_PATTERNS = ["CRIT:", "ERROR:", "WARNING:", "crit:", "error:", "warning:"]
 PTEST = "crm_simulate"
 SSH_OPTS = "-o StrictHostKeyChecking=no -o EscapeChar=none -o ConnectTimeout=15"
 CHECK_LOG_LINES = 10
@@ -58,6 +58,7 @@ SYSSTATS_F = "sysstats.txt"
 TIME_F = "time.txt"
 OCFS2_F = "ocfs2.txt"
 SBD_F = "sbd.txt"
+QDEVICE_F = "quorum_qdevice_qnetd.txt"
 OSRELEASE = "/etc/os-release"
 TIME_FORMAT = "%Y-%m-%d %H:%M:%S"
 RESULT_TIME_SUFFIX = "%a-%d-%b-%Y"
