@@ -6,15 +6,21 @@ import argparse
 import multiprocessing
 import os
 import re
+import subprocess
 import sys
 import shutil
 import json
 import ast
 from inspect import getmembers, isfunction
+from io import StringIO
 from typing import List
 
-from crmsh import utils as crmutils
-from crmsh import config, log, userdir, corosync, tmpfiles, ui_cluster, sh
+import crmsh.sh
+import crmsh.report.sh
+import crmsh.user_of_host
+from crmsh import utils as crmutils, userdir
+from crmsh import constants as crmconstants
+from crmsh import config, log, tmpfiles, ui_cluster
 from crmsh.sh import ShellUtils
 
 
@@ -39,13 +45,14 @@ class Context:
         self.single: bool= config.report.single_node
         self.sensitive_regex_list: List[str] = []
         self.regex_list: List[str] = "CRIT: ERROR: error: warning: crit:".split()
-        self.ssh_askpw_node_list: List[str] = []
+        self.passwordless_shell_for_nodes = dict()
         self.me = crmutils.this_node()
         self.pe_dir: str
         self.cib_dir: str
         self.pcmk_lib_dir: str
         self.pcmk_exec_dir: str
         self.cores_dir_list: List[str]
+        self.trace_dir_list: List[str]
         self.dest: str
         self.dest_dir: str
         self.work_dir: str
@@ -59,8 +66,8 @@ class Context:
         self.compress_suffix: str
         self.main_node = self.me
 
-    def __str__(self) ->str:
-        return json.dumps(self.__dict__)
+    def __str__(self) -> str:
+        return json.dumps({k: v for k, v in self.__dict__.items() if k != 'passwordless_shell_for_nodes'})
 
     def __setattr__(self, name: str, value) -> None:
         """
@@ -198,7 +205,7 @@ def process_results(context: Context) -> None:
         cmd_compress = f"{context.compress_prog} > {context.dest_dir}/{context.dest}.tar{context.compress_suffix}"
         cmd = f"{cmd_cd_tar}|{cmd_compress}"
         logger.debug2(f"Running: {cmd}")
-        sh.cluster_shell().get_stdout_or_raise_error(cmd)
+        crmsh.sh.cluster_shell().get_stdout_or_raise_error(cmd)
 
     finalword(context)
 
@@ -234,17 +241,16 @@ def collect_for_nodes(context: Context) -> None:
     Start collectors on each node
     """
     process_list = []
-    for node in context.node_list:
-        if node in context.ssh_askpw_node_list:
-            node_str = f"{context.ssh_user}@{node}" if context.ssh_user else node
-            logger.info(f"Please provide password for {node_str}")
-            start_collector(node, context)
-        else:
+    if len(context.passwordless_shell_for_nodes) == len(context.node_list):
+        for node in context.node_list:
             p = multiprocessing.Process(target=start_collector, args=(node, context))
             p.start()
             process_list.append(p)
-    for p in process_list:
-        p.join()
+        for p in process_list:
+            p.join()
+    else:
+        for node in context.node_list:
+            start_collector(node, context)
 
 
 def start_collector(node: str, context: Context) -> None:
@@ -252,43 +258,48 @@ def start_collector(node: str, context: Context) -> None:
     Start collector at specific node
     """
     cmd = f"{constants.BIN_COLLECTOR} '{context}'"
-    err = ""
 
-    if node == context.me:
-        code, out, err = ShellUtils().get_stdout_stderr(cmd)
+    shell = context.passwordless_shell_for_nodes.get(node)
+    if shell is not None:
+        ret = shell.subprocess_run_without_input(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     else:
-        node = f"{context.ssh_user}@{node}" if context.ssh_user else node
+        # This is a last effort when passwordless ssh is not available
         cmd = cmd.replace('"', '\\"')
-        cmd = f'{crmutils.get_ssh_agent_str()} ssh {constants.SSH_OPTS} {node} "{context.sudo} {cmd}"'
-        code, out, err = sh.LocalShell().get_rc_stdout_stderr(context.ssh_user, cmd)
-
-    if code != 0:
-        logger.warning(err)
-    # ERROR/WARNING/DEBUG messages
-    if err:
-        print(err, file=sys.stderr)
-    if out == '':
+        ret = _interactive_ssh_run_as_root(node, context.ssh_user, cmd)
+    if ret.returncode != 0:
+        logger.warning(
+            'Failed to run collector on %s: %s: %s',
+            node, ret.returncode, crmsh.sh.Utils.decode_str(ret.stderr) if ret.stderr is not None else '',
+        )
         return
+    elif ret.stderr:
+        print(crmsh.sh.Utils.decode_str(ret.stderr), file=sys.stderr)
 
-    compress_data = ""
-    for data in out.split("\n"):
+    archive_data_literal = ""
+    for data in ret.stdout.decode('utf-8').split("\n"):
         if data.startswith(constants.COMPRESS_DATA_FLAG):
             # crm report data from collector
-            compress_data = data.lstrip(constants.COMPRESS_DATA_FLAG)
+            archive_data_literal = data.lstrip(constants.COMPRESS_DATA_FLAG)
         else:
             # INFO log data from collector
             print(data)
 
     try:
         # Safely evaluate the string representation of a tarball from push_data
-        data_object = ast.literal_eval(compress_data)
+        archive_data = ast.literal_eval(archive_data_literal)
     except (SyntaxError, ValueError) as e:
         logger.error(f"Error evaluating data: {e}")
         return
 
     # Extract the tarball in the specified working directory
-    cmd = f"cd {context.work_dir} && tar x"
-    ShellUtils().get_stdout(cmd, input_s=data_object)
+    child = subprocess.Popen(
+        ['tar', '-x'],
+        cwd=context.work_dir,
+        stdin=subprocess.PIPE,
+    )
+    child.stdin.write(archive_data)
+    child.stdin.close()
+    child.wait()
 
 
 def process_dest(context: Context) -> None:
@@ -322,19 +333,26 @@ def process_dest(context: Context) -> None:
         context.dest_path = f"{context.dest_dir}/{context.dest}.tar{context.compress_suffix}"
 
 
+def local_mode(context: Context) -> bool:
+    return context.single or (len(context.node_list) == 1 and context.node_list[0] == context.me)
+
+
 def process_node_list(context: Context) -> None:
-    if not context.node_list:
+    if not local_mode(context) and config.core.no_ssh:
+        logger.error('%s', crmconstants.NO_SSH_ERROR_MSG)
+        context.single = True
+    if context.single:
+        context.node_list = [context.me]
+    elif not context.node_list:
         context.node_list = crmutils.list_cluster_nodes()
         if not context.node_list:
             raise utils.ReportGenericError("Could not figure out a list of nodes; is this a cluster node?")
-    if context.single:
-        context.node_list = [context.me]
 
     for node in context.node_list[:]:
         if node == context.me:
             continue
         try:
-            crmutils.ping_node(node)
+            crmutils.node_reachable_check(node)
         except Exception as err:
             logger.error(str(err))
             context.node_list.remove(node)
@@ -377,36 +395,27 @@ def find_ssh_user(context: Context) -> None:
     """
     Finds the SSH user for passwordless SSH access to nodes in the context's node_list
     """
-    ssh_user = ""
-    user_try_list = [
-            context.ssh_user,
-            userdir.get_sudoer(),
-            userdir.getuser()
-        ]
-
+    cluster_shell = crmsh.sh.cluster_shell()
+    user_of_host = crmsh.user_of_host.UserOfHost.instance()
     for n in context.node_list:
-        if n == context.me:
-            continue
-        rc = False
-        for u in user_try_list:
-            if not u:
-                continue
-            ssh_str = f"{u}@{n}"
-            if not crmutils.check_ssh_passwd_need(u, u, n):
-                logger.debug(f"ssh {ssh_str} OK")
-                ssh_user = u
-                rc = True
-                break
-            else:
-                logger.debug(f"ssh {ssh_str} failed")
-        if not rc:
-            context.ssh_askpw_node_list.append(n)
-    if context.ssh_askpw_node_list:
-        logger.warning(f"passwordless ssh to node(s) {context.ssh_askpw_node_list} does not work")
-
-    context.sudo = "" if ssh_user in ("root", "hacluster") else "sudo"
-    context.ssh_user = ssh_user or ""
-    logger.debug2(f"context.ssh_user is {context.ssh_user}")
+        ret = crmsh.report.sh.Shell.find_shell(cluster_shell, n, context.ssh_user)
+        if ret is not None:
+            logger.debug("passwordless ssh to %s is OK", n)
+            context.passwordless_shell_for_nodes[n] = ret
+        elif user_of_host.use_ssh_agent() and 'SSH_AUTH_SOCK' not in os.environ:
+            with StringIO() as buf:
+                buf.write('Environment variable SSH_AUTH_SOCK does not exist.')
+                if 'SUDO_USER' in os.environ:
+                    buf.write(' Please check whether ssh-agent is available and consider using "sudo --preserve-env=SSH_AUTH_SOCK".')
+                logger.warning('%s', buf.getvalue())
+        else:
+            logger.warning("passwordless ssh to node %s does not work", n)
+            if not crmutils.can_ask():
+                logger.error('Cannot create a report non-interactively. Interactive authentication is required.')
+                if userdir.getuser() == 'hacluster':
+                    raise ValueError('Passwordless ssh does not work. Run "crm cluster health hawk2 --fix" to set it up.')
+                else:
+                    raise ValueError('Cannot create a report.')
 
 
 def load_from_crmsh_config(context: Context) -> None:
@@ -441,6 +450,38 @@ def load_context_attributes(context: Context) -> None:
     context.cores_dir_list.extend([constants.COROSYNC_LIB] if os.path.isdir(constants.COROSYNC_LIB) else [])
 
 
+def load_context_trace_dir_list(context: Context) -> None:
+    # since the "trace_dir" attribute been removed from cib after untrace
+    # need to parse crmsh log file to extract custom trace ra log directory on each node
+    log_contents = ""
+    cmd = f"grep 'INFO: Trace for .* is written to ' {log.CRMSH_LOG_FILE}*|grep -v 'collect'"
+    for node in context.node_list:
+        shell = context.passwordless_shell_for_nodes.get(node)
+        if shell is not None:
+            ret = shell.subprocess_run_without_input(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        else:
+            # This is a last effort when passwordless ssh is not available
+            cmd = cmd.replace('"', '\\"')
+            ret = _interactive_ssh_run_as_root(node, context.ssh_user, cmd)
+        if ret.returncode == 0:
+            log_contents += ret.stdout.decode('utf-8')
+    context.trace_dir_list = list(set(re.findall("written to (.*)/.*", log_contents)))
+
+
+def _interactive_ssh_run_as_root(host: str, ssh_user: str, cmd: str):
+    # cmd MUST be escaped to make sure it works as an arugment of ssh command
+    target = f"{ssh_user}@{host}" if ssh_user else host
+    logger.info('Creating ssh connection to %s...', target)
+    cmd = 'ssh {} {} "{}{}"'.format(
+        constants.SSH_OPTS,
+        target,
+        '' if ssh_user is None or ssh_user == 'root' else 'sudo ',
+        cmd,
+    )
+    shell = crmsh.sh.LocalShell()
+    return shell.su_subprocess_run(None, cmd, tty=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+
+
 def adjust_verbosity(context: Context) -> None:
     if context.debug > 0:
         config.report.verbosity = context.debug
@@ -490,6 +531,7 @@ def run_impl() -> None:
         push_data(ctx)
     else:
         find_ssh_user(ctx)
+        load_context_trace_dir_list(ctx)
         collect_for_nodes(ctx)
         process_results(ctx)
 
