@@ -29,6 +29,17 @@ class LogType(Enum):
     AFTER_TIMESPAN = 4   # log after timespan; exclude
 
 
+def convert_logtype_to_str(log_type: LogType) -> str:
+    log_type_str = {
+        LogType.GOOD: "in timespan",
+        LogType.IRREGULAR: "irregular",
+        LogType.EMPTY: "empty",
+        LogType.BEFORE_TIMESPAN: "before timespan",
+        LogType.AFTER_TIMESPAN: "after timespan"
+    }
+    return log_type_str[log_type]
+
+
 class ReportGenericError(Exception):
     pass
 
@@ -43,14 +54,22 @@ def arch_logs(context: core.Context, logf: str) -> Tuple[List[str], LogType]:
     file_list = [logf] + glob.glob(logf+"*[0-9z]")
     # like ls -t, newest first
     for f in sorted(file_list, key=os.path.getmtime, reverse=True):
+        modify_time = os.path.getmtime(f)
+        if context.from_time > modify_time:
+            break # no need to check the rest
         tmp = is_our_log(context, f)
+        logger.debug2("File %s is %s", f, convert_logtype_to_str(tmp))
         if tmp not in (LogType.GOOD, LogType.IRREGULAR):
             continue
         log_type = tmp
         return_list.append(f)
 
     if return_list:
-        logger.debug2(f"Found logs {return_list} in {get_timespan_str(context)}")
+        logger.debug2(
+            "Found %s logs: %s",
+            convert_logtype_to_str(log_type),
+            ', '.join(return_list)
+        )
     return return_list, log_type
 
 
@@ -137,15 +156,15 @@ def extract_critical_log(context: core.Context) -> List[str]:
     Extract warnings and errors from collected log files
     """
     result_list = []
-    log_pattern_list = [f".*{p}.*" for p in constants.LOG_PATTERNS.split()]
-    log_pattern_str = '|'.join(log_pattern_list)
+    grep_e_option_str = f"-e {' -e '.join(constants.LOG_PATTERNS)}"
+    shell = sh.ShellUtils()
 
     for f in glob.glob(f"{context.work_dir}/*/*.log"):
-        _list = re.findall(log_pattern_str, crmutils.read_from_file(f))
-        if _list:
-            result_list.append(f"\nWARNINGS or ERRORS in {'/'.join(f.split('/')[3:])}:")
-            result_list.extend(_list)
-
+        grep_cmd = f"grep -F {grep_e_option_str} {f}"
+        _, out, _ = shell.get_stdout_stderr(grep_cmd)
+        if out:
+            result_list.append(f"\nWARNINGS or ERRORS in {real_path(f)}:")
+            result_list.append(out)
     return result_list
 
 
@@ -500,7 +519,9 @@ class Sanitizer:
         """
         Prepare the data and files for the sanitization process
         """
-        self._load_cib_from_work_dir()
+        self.cib_data = self._load_cib_from_work_dir()
+        if not self.cib_data:
+            return False
         self._parse_sensitive_set()
         self._extract_sensitive_value_list()
 
@@ -508,11 +529,13 @@ class Sanitizer:
             if not self.context.sanitize:
                 logger.warning("Some PE/CIB/log files contain possibly sensitive data")
                 logger.warning("Using \"-s\" option can replace sensitive data")
-                return
+                return False
             self._get_file_list_in_work_dir()
         else:
             self.context.sanitize = False
 
+        return True
+
     def _include_sensitive_data(self) -> List[str]:
         """
         Check whether contain sensitive data
@@ -533,11 +556,8 @@ class Sanitizer:
         """
         cib_file_list = glob.glob(f"{self.context.work_dir}/*/{constants.CIB_F}")
         if not cib_file_list:
-            raise ReportGenericError(f"CIB file {constants.CIB_F} was not collected")
-        data = crmutils.read_from_file(cib_file_list[0])
-        if not data:
-            raise ReportGenericError(f"File {cib_file_list[0]} is empty")
-        self.cib_data = data
+            return None
+        return crmutils.read_from_file(cib_file_list[0])
 
     def _parse_sensitive_set(self) -> None:
         """
@@ -588,11 +608,11 @@ class Sanitizer:
         replace_n: int = 0
 
         if self.sensitive_value_list_with_raw_option:
-            patt_str = '|'.join(self.sensitive_value_list_with_raw_option)
+            patt_str = '|'.join([re.escape(patt) for patt in self.sensitive_value_list_with_raw_option])
             result, replace_raw_n = re.subn(r'\b({})\b'.format(patt_str), "******", data)
         if self.sensitive_value_list:
             key_str = '|'.join(self.sensitive_key_list)
-            patt_str = '|'.join(self.sensitive_value_list)
+            patt_str = '|'.join([re.escape(patt) for patt in self.sensitive_value_list])
             result, replace_n = re.subn(f'({key_str})({patt_str})', '\\1******', result)
 
         return "" if (replace_raw_n == 0 and replace_n == 0) else result
@@ -619,8 +639,8 @@ def do_sanitize(context: core.Context) -> None:
     Perform sanitization by replacing sensitive information in CIB/PE/other logs data with '*'
     """
     inst = Sanitizer(context)
-    inst.prepare()
-    inst.sanitize()
+    if inst.prepare():
+        inst.sanitize()
 
 
 class Package:
