@@ -321,6 +321,7 @@ class SBDManager(object):
             if not utils.is_block_device(dev):
                 raise ValueError("{} doesn't look like a block device".format(dev))
             self._compare_device_uuid(dev, compare_node_list)
+        utils.detect_duplicate_device_path(dev_list)
 
     def _no_overwrite_check(self, dev):
         """
@@ -457,9 +458,7 @@ class SBDManager(object):
         Try to configure sbd resource, restart cluster on needed
         """
         if not xmlutil.CrmMonXmlParser().is_any_resource_running():
-            logger.info("Restarting cluster service")
-            utils.cluster_run_cmd("crm cluster restart")
-            bootstrap.wait_for_cluster()
+            bootstrap.restart_cluster()
             self.configure_sbd_resource_and_properties()
         else:
             logger.warning("To start sbd.service, need to restart cluster service manually on each node")
