@@ -15,7 +15,7 @@ There many variant of the methods to allow fine-gain control of parameter passin
    configurations.
 4. ShellUtils runs command on local host as current user. It is a simple wrapper around subprocess module.
 
-The LocalShell and SshShell is expected to be used in ssh bootstrap. Once the ssh bootstrap finishes, AuthShell should
+The LocalShell and SSHShell is expected to be used in ssh bootstrap. Once the ssh bootstrap finishes, ClusterShell should
 be used.
 """
 import logging
@@ -56,15 +56,23 @@ class AuthorizationError(Error):
         self.host = host
         self.user = user
 
-    @staticmethod
-    def diagnose() -> str:
-        if user_of_host.instance().use_ssh_agent():
-            with StringIO() as buf:
+    def diagnose(self) -> str:
+        with StringIO() as buf:
+            if user_of_host.instance().use_ssh_agent():
                 if 'SSH_AUTH_SOCK' not in os.environ:
                     buf.write('Environment variable SSH_AUTH_SOCK does not exist.')
                     if 'SUDO_USER' in os.environ:
                         buf.write(' Please check whether ssh-agent is available and consider using "sudo --preserve-env=SSH_AUTH_SOCK".')
-                return buf.getvalue()
+            return buf.getvalue()
+
+
+class NonInteractiveSSHAuthorizationError(AuthorizationError):
+
+    def diagnose(self) -> str:
+        ret = super().diagnose()
+        if not ret:
+            return 'Please configure passwordless authentication with "crm cluster init ssh" and "crm cluster join ssh"'
+        return ret
 
 
 class CommandFailure(Error):
@@ -79,6 +87,14 @@ class CommandFailure(Error):
             super().__init__("Failed to run command as {}@{}: '{}': {}".format(user, host, cmd, msg), cmd)
         self.host = host
         self.user = user
+        self.cmd = cmd
+        self.msg = msg
+
+    def __reduce__(self):
+        '''
+        Return a tuple that Python will use for pickling this object
+        '''
+        return CommandFailure, (self.cmd, self.host, self.user, self.msg)
 
 
 class Utils:
@@ -143,12 +159,12 @@ class LocalShell:
             )
         if not self.additional_environ:
             logger.debug('su_subprocess_run: %s, %s', args, kwargs)
-            return subprocess.run(args, **kwargs)
+            env = os.environ    # bsc#1205925
         else:
             logger.debug('su_subprocess_run: %s, env=%s, %s', args, self.additional_environ, kwargs)
             env = dict(os.environ)
             env.update(self.additional_environ)
-            return subprocess.run(args, env=env, **kwargs)
+        return subprocess.run(args, env=env, **kwargs)
 
     def get_rc_stdout_stderr_raw(self, user: typing.Optional[str], cmd: str, input: typing.Optional[bytes] = None):
         result = self.su_subprocess_run(
@@ -261,6 +277,7 @@ class SSHShell:
             return subprocess.run(
                 args,
                 input=cmd.encode('utf-8'),
+                env=os.environ,     # bsc#1205925
                 **kwargs,
             )
         else:
@@ -297,6 +314,8 @@ class ClusterShell:
                 stdout=subprocess.DEVNULL,
                 stderr=subprocess.DEVNULL,
             )
+        except crmsh.sh.AuthorizationError:
+            return False
         except user_of_host.UserNotFoundError:
             return False
         return 0 == result.returncode
@@ -308,6 +327,7 @@ class ClusterShell:
                 return subprocess.run(
                     ['/bin/sh'],
                     input=cmd.encode('utf-8'),
+                    env=os.environ,  # bsc#1205925
                     **kwargs,
                 )
             else:
@@ -335,7 +355,10 @@ class ClusterShell:
                 **kwargs,
             )
             if self.raise_ssh_error and result.returncode == 255:
-                raise AuthorizationError(cmd, host, remote_user, Utils.decode_str(result.stderr).strip())
+                raise NonInteractiveSSHAuthorizationError(
+                    cmd, host, remote_user,
+                    Utils.decode_str(result.stderr).strip() if result.stderr is not None else ''
+                )
             else:
                 return result
 
@@ -424,6 +447,7 @@ class ShellUtils:
             stdin=subprocess.PIPE,
             stdout=subprocess.PIPE,
             stderr=subprocess.DEVNULL if stderr_on else subprocess.PIPE,
+            env=os.environ,  # bsc#1205925
         )
         stdout_data, _ = proc.communicate(input_s)
         if raw:
@@ -445,7 +469,9 @@ class ShellUtils:
             shell=shell,
             stdin=input_s and subprocess.PIPE or None,
             stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE)
+            stderr=subprocess.PIPE,
+            env=os.environ,  # bsc#1205925
+        )
         # will raise subprocess.TimeoutExpired if set timeout
         stdout_data, stderr_data = proc.communicate(input_s, timeout=timeout)
         if raw:
@@ -477,3 +503,4 @@ class ClusterShellAdaptorForLocalShell(ClusterShell):
 
 def cluster_shell():
     return ClusterShell(LocalShell(), user_of_host.instance(), raise_ssh_error=True)
+
