@@ -9,13 +9,14 @@ import typing
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
 import crmsh.parallax
-from . import command, sh
+from . import command, sh, healthcheck
 from . import utils
 from . import scripts
 from . import completers as compl
 from . import bootstrap
 from . import corosync
 from . import qdevice
+from . import xmlutil
 from .cibconfig import cib_factory
 from .prun import prun
 from .service_manager import ServiceManager
@@ -25,32 +26,23 @@ from . import constants
 
 
 from . import log
+from .utils import TerminateSubCommand
+
 logger = log.setup_logger(__name__)
 
 
 def parse_options(parser, args):
     try:
         options, args = parser.parse_known_args(list(args))
-    except:
+    except Exception:
         return None, None
     if hasattr(options, 'help') and options.help:
         parser.print_help()
-        return None, None
+        raise TerminateSubCommand(success=True)
     utils.check_empty_option_value(options)
     return options, args
 
 
-def _remove_completer(args):
-    try:
-        n = utils.list_cluster_nodes()
-    except:
-        n = []
-    for node in args[1:]:
-        if node in n:
-            n.remove(node)
-    return scripts.param_completion_list('remove') + n
-
-
 def script_printer():
     from .ui_script import ConsolePrinter
     return ConsolePrinter()
@@ -178,10 +170,15 @@ class Cluster(command.UI):
 
         service_manager = ServiceManager()
         node_list = parse_option_for_nodes(context, *args)
-        for node in node_list[:]:
-            if all([service_manager.service_is_active(srv, remote_addr=node) for srv in service_check_list]):
-                logger.info("The cluster stack already started on {}".format(node))
-                node_list.remove(node)
+        try:
+            for node in node_list[:]:
+                if all([service_manager.service_is_active(srv, remote_addr=node) for srv in service_check_list]):
+                    logger.info("The cluster stack already started on {}".format(node))
+                    node_list.remove(node)
+        except utils.NoSSHError as msg:
+            logger.error('%s', msg)
+            logger.info("Please try 'crm cluster start' on each node")
+            return
         if not node_list:
             return
 
@@ -254,7 +251,12 @@ class Cluster(command.UI):
         Stops the cluster stack on all nodes or specific node(s)
         '''
         node_list = parse_option_for_nodes(context, *args)
-        node_list = [n for n in node_list if self._node_ready_to_stop_cluster_service(n)]
+        try:
+            node_list = [n for n in node_list if self._node_ready_to_stop_cluster_service(n)]
+        except utils.NoSSHError as msg:
+            logger.error('%s', msg)
+            logger.info("Please try 'crm cluster stop' on each node")
+            return
         if not node_list:
             return
         logger.debug(f"stop node list: {node_list}")
@@ -323,18 +325,11 @@ class Cluster(command.UI):
             return args + ['%s=%s' % (name, ','.join(vals))]
         return args
 
-    # @command.completers_repeating(compl.call(scripts.param_completion_list, 'init'))
     @command.skill_level('administrator')
     def do_init(self, context, *args):
         '''
         Initialize a cluster.
         '''
-        def looks_like_hostnames(lst):
-            sectionlist = bootstrap.INIT_STAGES
-            return all(not (l.startswith('-') or l in sectionlist) for l in lst)
-        if len(args) > 0:
-            if '--dry-run' in args or looks_like_hostnames(args):
-                args = ['--yes', '--nodes'] + [arg for arg in args if arg != '--dry-run']
         parser = ArgumentParser(description="""
 Initialize a cluster from scratch. This command configures
 a complete cluster, and can also add additional cluster
@@ -434,7 +429,7 @@ Examples:
                                    help="Configure corosync use IPv6")
 
         qdevice_group = parser.add_argument_group("QDevice configuration", re.sub('  ', '', constants.QDEVICE_HELP_INFO) + "\n\nOptions for configuring QDevice and QNetd.")
-        qdevice_group.add_argument("--qnetd-hostname", dest="qnetd_addr", metavar="[USER@]HOST",
+        qdevice_group.add_argument("--qnetd-hostname", dest="qnetd_addr_input", metavar="[USER@]HOST",
                                    help="User and host of the QNetd server. The host can be specified in either hostname or IP address.")
         qdevice_group.add_argument("--qdevice-port", dest="qdevice_port", metavar="PORT", type=int, default=5403,
                                    help="TCP PORT of QNetd server (default:5403)")
@@ -443,7 +438,7 @@ Examples:
         qdevice_group.add_argument("--qdevice-tie-breaker", dest="qdevice_tie_breaker", metavar="TIE_BREAKER", default="lowest",
                                    help="QNetd TIE_BREAKER (lowest/highest/valid_node_id, default:lowest)")
         qdevice_group.add_argument("--qdevice-tls", dest="qdevice_tls", metavar="TLS", default="on", choices=['on', 'off', 'required'],
-                                   help="Whether using TLS on QDevice/QNetd (on/off/required, default:on)")
+                                   help="Whether using TLS on QDevice (on/off/required, default:on)")
         qdevice_group.add_argument("--qdevice-heuristics", dest="qdevice_heuristics", metavar="COMMAND",
                                    help="COMMAND to run with absolute path. For multiple commands, use \";\" to separate (details about heuristics can see man 8 corosync-qdevice)")
         qdevice_group.add_argument("--qdevice-heuristics-mode", dest="qdevice_heuristics_mode", metavar="MODE", choices=['on', 'sync', 'off'],
@@ -469,10 +464,8 @@ Examples:
         if stage == "vgfs":
             stage = "ocfs2"
             logger.warning("vgfs stage was deprecated and is an alias of ocfs2 stage now")
-        if stage not in bootstrap.INIT_STAGES and stage != "":
-            parser.error("Invalid stage (%s)" % (stage))
 
-        if options.qnetd_addr:
+        if options.qnetd_addr_input:
             if not ServiceManager().service_is_available("corosync-qdevice.service"):
                 utils.fatal("corosync-qdevice.service is not available")
             if options.qdevice_heuristics_mode and not options.qdevice_heuristics:
@@ -545,12 +538,11 @@ Examples:
         stage = ""
         if len(args) == 1:
             stage = args[0]
-        if stage not in ("ssh", "csync2", "ssh_merge", "cluster", ""):
-            parser.error("Invalid stage (%s)" % (stage))
 
         join_context = bootstrap.Context.set_context(options)
         join_context.ui_context = context
         join_context.stage = stage
+        join_context.cluster_is_running = ServiceManager(sh.ClusterShellAdaptorForLocalShell(sh.LocalShell())).service_is_active("pacemaker.service")
         join_context.type = "join"
         join_context.validate_option()
 
@@ -559,7 +551,7 @@ Examples:
         return True
 
     @command.alias("delete")
-    @command.completers_repeating(_remove_completer)
+    @command.completers_repeating(compl.nodes)
     @command.skill_level('administrator')
     def do_remove(self, context, *args):
         '''
@@ -595,6 +587,7 @@ the config.core.force option.""",
             for node in args:
                 rm_context.cluster_node = node
                 bootstrap.bootstrap_remove(rm_context)
+                print()
         return True
 
     @command.skill_level('administrator')
@@ -602,8 +595,17 @@ the config.core.force option.""",
         '''
         Rename the cluster.
         '''
-        if not ServiceManager(sh.ClusterShellAdaptorForLocalShell(sh.LocalShell())).service_is_active("corosync.service"):
+        service_manager = ServiceManager()
+        if not service_manager.service_is_active("corosync.service"):
             context.fatal_error("Can't rename cluster when cluster service is stopped")
+        if service_manager.service_is_active("corosync-qdevice.service"):
+            logger.error("Can't rename cluster when QDevice service is running")
+            suggestion = '''Please run `crm cluster remove --qdevice` on any node in the cluster to remove the QDevice configuration;
+Then rename the cluster;
+Finally run `crm cluster init qdevice` on any node in the cluster to re-deploy the QDevice.'''
+            logger.info(suggestion)
+            return
+
         old_name = cib_factory.get_property('cluster-name')
         if old_name and new_name == old_name:
             context.fatal_error("Expected a different name")
@@ -621,8 +623,11 @@ the config.core.force option.""",
         if not cib_factory.commit():
             context.fatal_error("Change property cluster-name failed!")
 
-        # it's a safe way to give user a hints that need to restart service
-        context.info("To apply the change, restart the cluster service at convenient time")
+        if xmlutil.CrmMonXmlParser().is_any_resource_running():
+            context.info("To apply the change, restart the cluster service at convenient time")
+        else:
+            bootstrap.restart_cluster()
+
 
     def _parse_clustermap(self, clusters):
         '''
@@ -733,6 +738,8 @@ an existing cluster.""",
         parser.add_argument("-y", "--yes", help='Answer "yes" to all prompts (use with caution)', action="store_true", dest="yes_to_all")
         parser.add_argument("-c", "--cluster-node", metavar="[USER@]HOST", help="An already-configured geo cluster or arbitrator", dest="cluster_node")
         parser.add_argument("-s", "--clusters", help="Geo cluster description (see geo-init for details)", dest="clusters", metavar="DESC")
+        parser.add_argument('--use-ssh-agent', action='store_true', dest='use_ssh_agent',
+                            help="Use an existing key from ssh-agent instead of creating new key pairs")
         options, args = parse_options(parser, args)
         if options is None or args is None:
             return
@@ -782,20 +789,53 @@ to get the geo cluster configuration.""",
         bootstrap.bootstrap_arbitrator(geo_context)
         return True
 
-    @command.completers_repeating(compl.call(scripts.param_completion_list, 'health'))
+    @command.completers(compl.choice(['hawk2']))
     def do_health(self, context, *args):
         '''
         Extensive health check.
         '''
+        if not args:
+            return self._do_health_legacy(context, *args)
+        parser = argparse.ArgumentParser()
+        parser.add_argument('component', choices=['hawk2'])
+        parser.add_argument('-f', '--fix', action='store_true')
+        parsed_args = parser.parse_args(args)
+        if parsed_args.component == 'hawk2':
+            nodes = utils.list_cluster_nodes()
+            if parsed_args.fix:
+                if not healthcheck.feature_full_check(healthcheck.PasswordlessPrimaryUserAuthenticationFeature(), nodes):
+                    try:
+                        healthcheck.feature_fix(
+                            healthcheck.PasswordlessPrimaryUserAuthenticationFeature(),
+                            nodes,
+                            utils.ask,
+                        )
+                    except healthcheck.FixFailure:
+                        logger.error('Cannot fix automatically.')
+                        return False
+                try:
+                    healthcheck.feature_fix(healthcheck.PasswordlessHaclusterAuthenticationFeature(), nodes, utils.ask)
+                    logger.info("hawk2: passwordless ssh authentication: OK.")
+                    return True
+                except healthcheck.FixFailure:
+                    logger.error("hawk2: passwordless ssh authentication: FAIL.")
+                    return False
+            else:
+                if healthcheck.feature_full_check(healthcheck.PasswordlessHaclusterAuthenticationFeature(), nodes):
+                    logger.info("hawk2: passwordless ssh authentication: OK.")
+                    return True
+                else:
+                    logger.error("hawk2: passwordless ssh authentication: FAIL.")
+                    logger.warning('Please run "crm cluster health hawk2 --fix"')
+                    return False
+
+    def _do_health_legacy(self, context, *args):
         params = self._args_implicit(context, args, 'nodes')
         script = scripts.load_script('health')
         if script is None:
             raise ValueError("health script failed to load")
         return scripts.run(script, script_args(params), script_printer())
 
-    def _node_in_cluster(self, node):
-        return node in utils.list_cluster_nodes()
-
     def do_status(self, context):
         '''
         Quick cluster health status. Corosync status, DRBD status...
