@@ -231,7 +231,10 @@ def _prim_params_completer(agent, args):
         return []
     elif '=' in completing:
         return []
-    return utils.filter_keys(agent.params(completion=True), args)
+    if command.sort_completion_inst is not None:
+        # Set the value to 0 to use the costum sort order
+        command.sort_completion_inst.value = 0
+    return utils.filter_keys(agent.params(), args)
 
 
 def _prim_meta_completer(agent, args):
@@ -343,7 +346,9 @@ def primitive_complete_complex(args):
 
 def container_helptxt(params, helptxt, topic):
     for item in reversed(params):
-        if item in ["storage", "network", "docker", "rkt"]:
+        if item in constants.container_type:
+            return helptxt["container"][topic] + "\n"
+        if item in ("storage", "network"):
             return helptxt[item][topic] + "\n"
         if item == "port-mapping":
             return helptxt["network"][item][topic] + "\n"
@@ -452,7 +457,6 @@ def container_complete_complex(args):
     '''
     container_options_required = ["image"]
     completing = args[-1]
-    container_type = args[2]
 
     completers_set = {
         "network": _container_network_completer,
@@ -470,7 +474,7 @@ def container_complete_complex(args):
             CompletionHelp.help(topic, container_helptxt(args, constants.container_helptxt, topic), args)
         return []
 
-    container_options = utils.filter_keys(constants.container_helptxt[container_type].keys(), args)
+    container_options = utils.filter_keys(constants.container_helptxt["container"].keys(), args)
 
     # required options must be completed
     for s in container_options_required:
@@ -496,8 +500,8 @@ class CibConfig(command.UI):
         # immediately so that tab completion works
 
     def requires(self):
-        if not cib_factory.initialize():
-            return False
+        if not cib_factory.initialize(no_side_effects=True):
+            return True
         # see the configure ptest/simulate command
         has_ptest = utils.is_program('ptest')
         has_simulate = utils.is_program('crm_simulate')
@@ -562,6 +566,7 @@ class CibConfig(command.UI):
     def do_show(self, context, *args):
         "usage: show [xml] [<id>...]"
         from .utils import obscure
+        utils.load_cib_file_env()
         osargs = [arg[8:] for arg in args if arg.startswith('obscure:')]
         if not osargs and config.core.obscure_pattern:
             # obscure_pattern could be
@@ -581,6 +586,7 @@ class CibConfig(command.UI):
     @command.completers_repeating(compl.call(ra.get_properties_list))
     def do_get_property(self, context, *args):
         "usage: get-property [-t|--true [<name>...]"
+        utils.load_cib_file_env()
         properties = [a for a in args if a not in ('-t', '--true')]
         truth = any(a for a in args if a in ('-t', '--true'))
 
@@ -648,14 +654,23 @@ class CibConfig(command.UI):
                 context.fatal_error("Operation \"{}\" not found for resource {}".format(op_type, obj_id))
             if len(op_res) > 1:
                 context.fatal_error("Should specify interval of {}".format(op_type))
+            if name in ('interval', 'timeout'):
+                value = utils.add_time_unit_if_needed(value)
+            if name == 'interval':
+                op_res[0].set('id', f'{obj_id}-{op_type}-{value}')
             op_res[0].set(name, value)
 
         # Use case for: set id.op_type.interval.name value
         if len(other_path_list) == 3:
             op_type, iv, name = other_path_list
-            op_res = rsc.node.xpath(".//operations/op[@id='{}-{}-{}']".format(obj_id, op_type, iv))
+            iv = iv[:-1] if utils.time_value_with_unit(iv) else iv
+            # Search for IDs both with and without the associated time unit
+            op_res = rsc.node.xpath(f".//operations/op[@id='{obj_id}-{op_type}-{iv}' or @id='{obj_id}-{op_type}-{iv}s']")
             if not op_res:
-                context.fatal_error("Operation \"{}\" interval \"{}\" not found for resource {}".format(op_type, iv, obj_id))
+                context.fatal_error(f"Operation \"{op_type}\" interval \"{iv}s\" not found for resource {obj_id}")
+            if name == 'interval':
+                value = utils.add_time_unit_if_needed(value)
+                op_res[0].set('id', f'{obj_id}-{op_type}-{value}')
             op_res[0].set(name, value)
 
         rsc.set_updated()
@@ -730,6 +745,7 @@ class CibConfig(command.UI):
     @command.skill_level('administrator')
     def do_verify(self, context):
         "usage: verify"
+        utils.load_cib_file_env()
         cib_factory.ensure_cib_updated()
         set_obj_all = mkset_obj("xml")
         return self._verify(set_obj_all, set_obj_all)
@@ -866,9 +882,6 @@ class CibConfig(command.UI):
     @command.completers(compl.choice(['nodes']))
     def do_erase(self, context, nodes=None):
         "usage: erase [nodes]"
-        if not options.regression_tests:
-            logger.warning("`crm configure erase` is deprecated. The replacement could be `crm cluster remove [node]`")
-            return True
         cib_factory.ensure_cib_updated()
         if nodes is None:
             return cib_factory.erase()
@@ -904,8 +917,7 @@ class CibConfig(command.UI):
         rc1 = True
         if replace and not force:
             rc1 = cib_factory.is_current_cib_equal()
-        rc2 = cib_factory.has_no_primitives() or \
-            self._verify(mkset_obj("xml", "changed"), mkset_obj("xml"))
+        rc2 = self._verify(mkset_obj("xml", "changed"), mkset_obj("xml"))
         if rc1 and rc2:
             return cib_factory.commit(replace=replace)
         if force or config.core.force:
