@@ -16,6 +16,8 @@ from . import main
 logger = log.setup_logger(__name__)
 logger_utils = log.LoggerUtils(logger)
 
+_NON_FUNCTIONAL_COMMANDS = {'help', 'cd', 'ls', 'quit', 'up'}
+_NON_FUNCTIONAL_OPTIONS = {'--help', '--help-without-redirect'}
 
 class Context(object):
     """
@@ -82,13 +84,21 @@ class Context(object):
                     cmd = True
                     break
             if cmd:
+                if self.command_name not in _NON_FUNCTIONAL_COMMANDS\
+                        and all(arg not in _NON_FUNCTIONAL_OPTIONS for arg in self.command_args):
+                    entry = self.current_level()
+                    if 'requires' in dir(entry) and not entry.requires():
+                        self.fatal_error("Missing requirements")
                 utils.check_user_access(self.current_level().name)
                 rv = self.execute_command() is not False
         except (ValueError, IOError) as e:
             logger.error("%s: %s", self.get_qualified_name(), e, exc_info=e)
             rv = False
-        except utils.TerminateSubCommand:
-            return False
+        except utils.TerminateSubCommand as terminate:
+            if terminate.success:
+                rv = True
+            else:
+                return False
         if cmd or (rv is False):
             rv = self._back_out() and rv
 
@@ -220,7 +230,7 @@ class Context(object):
             ret = None
         # logging.debug("line:%s, text:%s, ret:%s, state:%s", repr(line), repr(text), ret, state)
         if not text or (ret and line.split()[-1].endswith(ret)):
-            if ret == "id=":
+            if ret.endswith('='):
                 return ret
             return ret + ' '
         return ret
@@ -236,8 +246,7 @@ class Context(object):
     def enter_level(self, level):
         '''
         Pushes an instance of the given UILevel
-        subclass onto self.stack. Checks prerequirements
-        for the level (if any).
+        subclass onto self.stack.
         '''
         # on entering new level we need to set the
         # interactive option _before_ creating the level
