@@ -1,7 +1,7 @@
 # Copyright (C) 2008-2011 Dejan Muhamedagic <dmuhamedagic@suse.de>
 # Copyright (C) 2013 Kristoffer Gronlund <kgronlund@suse.com>
 # See COPYING for license information.
-
+import os
 import re
 import copy
 import subprocess
@@ -237,26 +237,26 @@ keep the node in standby after reboot. The life time defaults to
     options, args = parser.parse_known_args(args)
     if options.help:
         parser.print_help()
-        raise utils.TerminateSubCommand
+        raise utils.TerminateSubCommand(success=True)
     if options is None or args is None:
         raise utils.TerminateSubCommand
     if options.all and args:
         context.fatal_error("Should either use --all or specific node(s)")
 
     # return local node
-    if not options.all and not args:
+    if (not options.all and not args) or (len(args) == 1 and args[0] == utils.this_node()):
         return [utils.this_node()]
-    member_list = utils.list_cluster_nodes()
+    member_list = utils.list_cluster_nodes() or utils.get_address_list_from_corosync_conf()
     if not member_list:
         context.fatal_error("Cannot get the node list from cluster")
     for node in args:
         if node not in member_list:
-            context.fatal_error("Node \"{}\" is not a cluster node".format(node))
+            context.fatal_error(f"Node '{node}' is not a member of the cluster")
 
     node_list = member_list if options.all else args
     for node in node_list:
         try:
-            utils.ping_node(node)
+            utils.node_reachable_check(node)
         except ValueError as err:
             logger.warning(str(err))
             node_list.remove(node)
@@ -318,6 +318,7 @@ class NodeMgmt(command.UI):
     @command.completers(compl.nodes)
     def do_show(self, context, node=None):
         'usage: show [<node>]'
+        utils.load_cib_file_env()
         cib = xmlutil.cibdump2elem()
         if cib is None:
             return False
@@ -335,7 +336,9 @@ class NodeMgmt(command.UI):
             xml = find(uname, cfg_nodes)
             state = find(uname, node_states)
             if xml is not None or state is not None:
-                is_offline = state is not None and state.get("crmd") == "offline"
+                is_offline = state is not None and \
+                    (state.get("crmd") == "offline" or \
+                        (state.get("crmd").isdigit() and int(state.get("crmd")) == 0))
                 print_node(*unpack_node_xmldata(xml if xml is not None else state, is_offline))
 
         if node is not None:
@@ -376,6 +379,8 @@ class NodeMgmt(command.UI):
             xml_query_path_oppsite = constants.XML_NODE_QUERY_STANDBY_PATH
 
         cib = xmlutil.cibdump2elem()
+        if cib is None:
+            return False
         # IMPORTANT:
         # Do NOT call cibdump2elem twice, or you risk a race where the
         # resulting diff will contain more changes than the values for
@@ -434,6 +439,8 @@ class NodeMgmt(command.UI):
             return
 
         cib = xmlutil.cibdump2elem()
+        if cib is None:
+            return False
         # IMPORTANT: Do NOT call cibdump2elem twice, or you risk a race.
         # Really use the same xml as "original" and basis for the changes.
         # Thus the "deepcopy" here; see also do_standby().
@@ -478,6 +485,9 @@ class NodeMgmt(command.UI):
         'usage: fence <node>'
         if not utils.is_name_sane(node):
             return False
+        if not utils.has_stonith_running():
+            logger.error("fence command requires stonith device configured and running")
+            return False
         if not config.core.force and \
                 not utils.ask("Fencing %s will shut down the node and migrate any resources that are running on it! Do you want to fence %s?" % (node, node)):
             return False
@@ -501,13 +511,17 @@ class NodeMgmt(command.UI):
             cib_elem = xmlutil.cibdump2elem()
             if cib_elem is None:
                 return False
-            if cib_elem.xpath("//node_state[@uname=\"%s\"]/@crmd" % node) == ["online"]:
+            crmd = cib_elem.xpath("//node_state[@uname=\"%s\"]/@crmd" % node)
+            if not crmd:
+                logger.error("Node '%s' not found in CIB", node)
+                return False
+            if crmd == ["online"] or (crmd[0].isdigit() and int(crmd[0]) != 0):
                 return utils.ext_cmd(self.node_cleanup_resources % node) == 0
-            elif cib_elem.xpath("//node_state[@uname=\"%s\"]/@in_ccm" % node) == ["true"]:
+            in_ccm = cib_elem.xpath("//node_state[@uname=\"%s\"]/@in_ccm" % node)
+            if in_ccm == ["true"] or (in_ccm[0].isdigit() and int(in_ccm[0]) != 0):
                 logger.warning("Node is offline according to Pacemaker, but online according to corosync. First shut down node '%s'", node)
                 return False
-            else:
-                return utils.ext_cmd(self.node_clear_state_118 % node) == 0
+            return utils.ext_cmd(self.node_clear_state_118 % node) == 0
         else:
             return utils.ext_cmd(self.node_clear_state % ("-M -c", node, node)) == 0 and \
                 utils.ext_cmd(self.node_clear_state % ("-R", node, node)) == 0
@@ -550,10 +564,13 @@ class NodeMgmt(command.UI):
         'usage: delete <node>'
         logger.warning('`crm node delete` is deprecated and will very likely be dropped in the near future. It is auto-replaced as `crm cluster remove -c {}`.'.format(node))
         if config.core.force:
-            rc = subprocess.call(['crm', 'cluster', 'remove', '-F', '-c', node])
+            args = ['crm', 'cluster', 'remove', '-F', '-c', node]
         else:
-            rc = subprocess.call(['crm', 'cluster', 'remove', '-c', node])
-        return rc == 0
+            args = ['crm', 'cluster', 'remove', '-c', node]
+        return 0 == subprocess.call(
+            args,
+            env=os.environ,  # bsc#1205925
+        )
 
     @command.wait
     @command.completers(compl.nodes, compl.choice(['set', 'delete', 'show']), _find_attr)
@@ -603,6 +620,7 @@ class NodeMgmt(command.UI):
         server -- print server hostname / address for each node
         server <node> ... -- print server hostname / address for node
         """
+        utils.load_cib_file_env()
         cib = xmlutil.cibdump2elem()
         if cib is None:
             return False
