@@ -21,11 +21,13 @@ import ipaddress
 import argparse
 import random
 import string
+import pwd
 import grp
 import gzip
 import bz2
 import lzma
 from pathlib import Path
+from collections import defaultdict
 from contextlib import contextmanager, closing
 from stat import S_ISBLK
 from lxml import etree
@@ -52,6 +54,8 @@ class TerminateSubCommand(Exception):
     """
     This is an exception to jump out of subcommand when meeting errors while staying interactive shell
     """
+    def __init__(self, success=False):
+        self.success = success
 
 
 def to_ascii(input_str):
@@ -124,11 +128,13 @@ def user_pair_for_ssh(host):
         raise ValueError('Can not create ssh session from {} to {}.'.format(this_node(), host))
 
 
-def ssh_copy_id_no_raise(local_user, remote_user, remote_node):
-    if check_ssh_passwd_need(local_user, remote_user, remote_node):
+def ssh_copy_id_no_raise(local_user, remote_user, remote_node, shell: sh.LocalShell = None):
+    if shell is None:
+        shell = sh.LocalShell()
+    if check_ssh_passwd_need(local_user, remote_user, remote_node, shell):
         logger.info("Configuring SSH passwordless with {}@{}".format(remote_user, remote_node))
         cmd = "ssh-copy-id -i ~/.ssh/id_rsa.pub '{}@{}' &> /dev/null".format(remote_user, remote_node)
-        result = sh.LocalShell().su_subprocess_run(local_user, cmd, tty=True)
+        result = shell.su_subprocess_run(local_user, cmd, tty=True)
         return result.returncode
     else:
         return 0
@@ -150,13 +156,14 @@ _cib_in_use = ''
 
 
 def set_cib_in_use(name):
-    os.putenv(_cib_shadow, name)
+    os.environ[_cib_shadow] = name
     global _cib_in_use
     _cib_in_use = name
 
 
 def clear_cib_in_use():
-    os.unsetenv(_cib_shadow)
+    if _cib_shadow in os.environ:
+        del os.environ[_cib_shadow]
     global _cib_in_use
     _cib_in_use = ''
 
@@ -439,12 +446,10 @@ def chown(path, user, group):
     if isinstance(user, int):
         uid = user
     else:
-        import pwd
         uid = pwd.getpwnam(user).pw_uid
     if isinstance(group, int):
         gid = group
     else:
-        import grp
         gid = grp.getgrnam(group).gr_gid
     try:
         os.chown(path, uid, gid)
@@ -465,14 +470,6 @@ def chmod(path, mod):
             fatal("Failed to chmod {}: {}".format(path, err))
 
 
-def touch(file_name):
-    rc, out, err = ShellUtils().get_stdout_stderr("touch " + file_name, no_reg=True)
-    if rc != 0:
-        rc, out, err = ShellUtils().get_stdout_stderr("sudo touch " + file_name, no_reg=True)
-        if rc != 0:
-            fatal("Failed create file {}: {}".format(file_name, err))
-
-
 def copy_local_file(src, dest):
     try:
         shutil.copyfile(src, dest)
@@ -523,7 +520,12 @@ def pipe_string(cmd, s):
     logger.debug("piping string to %s", cmd)
     if options.regression_tests:
         print(".EXT", cmd)
-    p = subprocess.Popen(cmd, shell=True, stdin=subprocess.PIPE)
+    p = subprocess.Popen(
+        cmd,
+        shell=True,
+        stdin=subprocess.PIPE,
+        env=os.environ,  # bsc#1205925
+    )
     try:
         # communicate() expects encoded bytes
         if isinstance(s, str):
@@ -552,7 +554,9 @@ def filter_string(cmd, s, stderr_on=True, shell=True):
                          shell=shell,
                          stdin=subprocess.PIPE,
                          stdout=subprocess.PIPE,
-                         stderr=stderr)
+                         stderr=stderr,
+                         env=os.environ,  # bsc#1205925
+                         )
     try:
         # bytes expected here
         if isinstance(s, str):
@@ -673,22 +677,6 @@ def str2file(s, fname, mod=0o644):
             return False
     return True
 
-def write_remote_file(text, tofile, user, remote):
-    shell_script = f'''cat >> {tofile} << EOF
-{text}
-EOF
-'''
-    result = sh.cluster_shell().subprocess_run_without_input(
-        remote,
-        user,
-        shell_script,
-        stdout=subprocess.DEVNULL,
-        stderr=subprocess.PIPE,
-    )
-    if result.returncode != 0:
-        raise ValueError("Failed to write to {}@{}/{}: {}".format(user, remote, tofile, result.stdout.decode('utf-8')))
-
-
 def copy_remote_textfile(remote_user, remote_node, remote_text_file, local_path):
     """
     scp might lack permissions to copy the file for a non-root user.
@@ -770,7 +758,9 @@ def show_dot_graph(dotfile, keep_file=False, desc="transition graph"):
     if options.regression_tests:
         print(".EXT", cmd)
     subprocess.Popen(cmd, shell=True, bufsize=0,
-                     stdin=None, stdout=None, stderr=None, close_fds=True)
+                     stdin=None, stdout=None, stderr=None, close_fds=True,
+                     env=os.environ,  # bsc#1205925
+                     )
     logger.info("starting %s to show %s", config.core.dotty, desc)
 
 
@@ -779,13 +769,21 @@ def ext_cmd(cmd, shell=True):
     if options.regression_tests:
         print(".EXT", cmd)
     logger.debug("invoke: %s", cmd)
-    return subprocess.call(cmd, shell=shell)
+    return subprocess.call(
+        cmd,
+        shell=shell,
+        env=os.environ,  # bsc#1205925
+    )
 
 
 def ext_cmd_nosudo(cmd, shell=True):
     if options.regression_tests:
         print(".EXT", cmd)
-    return subprocess.call(cmd, shell=shell)
+    return subprocess.call(
+        cmd,
+        shell=shell,
+        env=os.environ,  # bsc#1205925
+    )
 
 
 def rmdir_r(d):
@@ -918,7 +916,9 @@ def pipe_cmd_nosudo(cmd):
     proc = subprocess.Popen(cmd,
                             shell=True,
                             stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE)
+                            stderr=subprocess.PIPE,
+                            env=os.environ,  # bsc#1205925
+                            )
     (outp, err_outp) = proc.communicate()
     proc.wait()
     rc = proc.returncode
@@ -1757,13 +1757,14 @@ def list_corosync_nodes():
         return []
 
 
-def print_cluster_nodes():
+def get_address_list_from_corosync_conf():
     """
-    Print the output of crm_node -l
+    Return a list of addresses configured in corosync.conf
     """
-    rc, out, _ = ShellUtils().get_stdout_stderr("crm_node -l")
-    if rc == 0 and out:
-        print("{}\n".format(out))
+    from . import corosync
+    if not os.path.exists(corosync.conf()):
+        return []
+    return corosync.get_values("nodelist.node.ring0_addr")
 
 
 def list_cluster_nodes(no_reg=False):
@@ -1788,9 +1789,10 @@ def list_cluster_nodes(no_reg=False):
     node_list = []
     for node in cib.xpath(constants.XML_NODE_PATH):
         name = node.get('uname') or node.get('id')
+        # exclude remote node
         if node.get('type') == 'remote':
-            srv = cib.xpath("//primitive[@id='%s']/instance_attributes/nvpair[@name='server']" % (name))
-            if srv:
+            xpath = f"//primitive[@provider='pacemaker' and @type='remote']/instance_attributes/nvpair[@name='server' and @value='{name}']"
+            if cib.xpath(xpath):
                 continue
         node_list.append(name)
     return node_list
@@ -2122,32 +2124,33 @@ def debug_timestamp():
     return datetime.datetime.now().strftime('%Y/%m/%d %H:%M:%S')
 
 
-def check_ssh_passwd_need(local_user, remote_user, host):
+def check_ssh_passwd_need(local_user, remote_user, host, shell: sh.LocalShell = None):
     """
     Check whether access to host need password
     """
     ssh_options = "-o StrictHostKeyChecking=no -o EscapeChar=none -o ConnectTimeout=15"
-    ssh_cmd = "{} ssh {} -T -o Batchmode=yes {}@{} true".format(get_ssh_agent_str(), ssh_options, remote_user, host)
-    rc, _ = sh.LocalShell().get_rc_and_error(local_user, ssh_cmd)
+    ssh_cmd = "ssh {} -T -o Batchmode=yes {}@{} true".format(ssh_options, remote_user, host)
+    if shell is None:
+        shell = sh.LocalShell()
+    rc, _ = shell.get_rc_and_error(local_user, ssh_cmd)
     return rc != 0
 
 
-def get_ssh_agent_str():
-    ssh_agent_str = ""
-    if crmsh.user_of_host.instance().use_ssh_agent():
-        ssh_agent_str = f"SSH_AUTH_SOCK={os.environ.get('SSH_AUTH_SOCK')}"
-    return ssh_agent_str
-
-
-def check_port_open(ip, port):
-    import socket
-
-    family = socket.AF_INET6 if IP.is_ipv6(ip) else socket.AF_INET
-    with closing(socket.socket(family, socket.SOCK_STREAM)) as sock:
-        if sock.connect_ex((ip, port)) == 0:
-            return True
-        else:
-            return False
+def check_port_open(host, port, timeout=3) -> bool:
+    """
+    Check whether the port is open on the host
+    Use getaddrinfo to support both IPv4 and IPv6
+    """
+    try:
+        addrinfo = socket.getaddrinfo(host, port, socket.AF_UNSPEC, socket.SOCK_STREAM)
+        af, socktype, proto, canonname, sa = addrinfo[0]
+        with closing(socket.socket(af, socktype, proto)) as sock:
+            sock.settimeout(timeout)
+            if sock.connect_ex(sa) == 0:
+                return True
+        return False
+    except socket.error:
+        return False
 
 
 def valid_port(port):
@@ -2465,22 +2468,6 @@ class InterfacesInfo(object):
         return _ip_list
 
 
-def check_file_content_included(source_file, target_file, remote=None, source_local=False):
-    """
-    Check whether target_file includes contents of source_file
-    """
-    if not detect_file(source_file, remote=None if source_local else remote):
-        raise ValueError("File {} not exist".format(source_file))
-    if not detect_file(target_file, remote=remote):
-        return False
-
-    shell = sh.cluster_shell()
-    cmd = "cat {}".format(target_file)
-    target_data = shell.get_stdout_or_raise_error(cmd, host=remote)
-    cmd = "cat {}".format(source_file)
-    source_data = shell.get_stdout_or_raise_error(cmd, host=None if source_local else remote)
-    return source_data in target_data
-
 def check_text_included(text, target_file, remote=None):
     "Check whether target_file includes the text"
     if not detect_file(target_file, remote=remote):
@@ -2505,13 +2492,18 @@ def package_is_installed(pkg, remote_addr=None):
     return rc == 0
 
 
-def ping_node(node):
+def node_reachable_check(node, ping_count=1, port=22, timeout=3):
     """
-    Check if the remote node is reachable
+    Check if node is reachable by using ping and socket to ssh port
     """
-    rc, _, err = ShellUtils().get_stdout_stderr("ping -c 1 {}".format(node))
-    if rc != 0:
-        raise ValueError("host \"{}\" is unreachable: {}".format(node, err))
+    rc, _, _ = ShellUtils().get_stdout_stderr(f"ping -n -c {ping_count} -W {timeout} {node}")
+    if rc == 0:
+        return True
+    # ping failed, try to connect to ssh port by socket
+    if check_port_open(node, port, timeout):
+        return True
+    # both ping and socket failed
+    raise ValueError(f"host \"{node}\" is unreachable")
 
 
 def calculate_quorate_status(expected_votes, actual_votes):
@@ -2535,7 +2527,7 @@ def check_all_nodes_reachable():
     """
     out = sh.cluster_shell().get_stdout_or_raise_error("crm_node -l")
     for node in re.findall("\d+ (.*) \w+", out):
-        ping_node(node)
+        node_reachable_check(node)
 
 
 def re_split_string(reg, string):
@@ -2556,6 +2548,19 @@ def is_block_device(dev):
     return rc
 
 
+def detect_duplicate_device_path(device_list: typing.List[str]):
+    """
+    Resolve device path and check if there are duplicated device path
+    """
+    path_dict = defaultdict(list)
+    for dev in device_list:
+        resolved_path = Path(dev).resolve()
+        path_dict[resolved_path].append(dev)
+    for path, dev_list in path_dict.items():
+        if len(dev_list) > 1:
+            raise ValueError(f"Duplicated device path detected: {','.join(dev_list)}. They are all pointing to {path}")
+
+
 def has_stonith_running():
     """
     Check if any stonith device registered
@@ -2859,11 +2864,12 @@ def set_property(property_name, property_value, property_type="crm_config", cond
     origin_value = get_property(property_name, property_type)
     if origin_value and str(origin_value) == str(property_value):
         return
-    if conditional:
-        if crm_msec(origin_value) >= crm_msec(property_value):
-            return
+    if conditional and crm_msec(origin_value) >= crm_msec(property_value):
+        return
+    if not origin_value and property_value:
+        logger.info("Set property \"%s\" in %s to %s", property_name, property_type, property_value)
     if origin_value and str(origin_value) != str(property_value):
-        logger.warning("\"{}\" in {} is set to {}, it was {}".format(property_name, property_type, property_value, origin_value))
+        logger.warning("\"%s\" in %s is set to %s, it was %s", property_name, property_type, property_value, origin_value)
     property_sub_cmd = "property" if property_type == "crm_config" else property_type
     cmd = "crm configure {} {}={}".format(property_sub_cmd, property_name, property_value)
     sh.cluster_shell().get_stdout_or_raise_error(cmd)
@@ -3015,7 +3021,7 @@ def in_haclient():
     """
     Check if current user is in haclient group
     """
-    return constants.HA_GROUP in [grp.getgrgid(g).gr_name for g in os.getgroups()]
+    return grp.getgrnam(constants.HA_GROUP).gr_gid in (os.getgroups() + [os.getegid()])
 
 
 def check_user_access(level_name):
@@ -3023,24 +3029,11 @@ def check_user_access(level_name):
     Check current user's privilege and give hints to user
     """
     current_user = userdir.getuser()
-    if current_user == "root":
-        return
-    if level_name != "cluster" and in_haclient():
+    if current_user == "root" or in_haclient():
         return
 
     if not has_sudo_access():
-        if level_name == "cluster":
-            hints = f"""Please run this command starting with "sudo".
-Currently, this command needs to use sudo to escalate itself as root.
-Please consider to add "{current_user}" as sudoer. For example:
-  sudo bash -c 'echo "{current_user} ALL=(ALL) NOPASSWD:ALL" > /etc/sudoers.d/{current_user}'"""
-        else:
-            hints = f"""This command needs higher privilege.
-Option 1) Please consider to add "{current_user}" as sudoer. For example:
-  sudo bash -c 'echo "{current_user} ALL=(ALL) NOPASSWD:ALL" > /etc/sudoers.d/{current_user}'
-Option 2) Add "{current_user}" to the haclient group. For example:
-  sudo usermod -g haclient {current_user}"""
-        logger.error(hints)
+        logger.error("Operation is denied. The current user lacks the necessary privilege.")
     else:
         logger.error("Please run this command starting with \"sudo\"")
     raise TerminateSubCommand
@@ -3097,6 +3090,10 @@ class HostUserConfig:
             'yes' if self._no_generating_ssh_key else 'no'
         ))
 
+    def clear(self):
+        self._hosts_users = dict()
+        self._no_generating_ssh_key = False
+
     def get(self, host):
         return self._hosts_users[host]
 
@@ -3142,9 +3139,53 @@ def read_from_file(infile: str) -> str:
     try:
         with _open(infile, 'rt', encoding='utf-8', errors='replace') as f:
             data = f.read()
+    except PermissionError as err:
+        logger.warning("When reading file \"%s\": %s", infile, str(err))
+        return ""
     except Exception as err:
         logger.error("When reading file \"%s\": %s", infile, str(err))
         return ""
 
     return data
+
+
+def add_time_unit_if_needed(time_value):
+    """
+    Add time unit if needed
+    """
+    return "{}s".format(time_value) if not time_value_with_unit(time_value) else time_value
+
+
+def time_value_with_unit(time_value):
+    """
+    Check if the time value contains unit
+    """
+    return re.search(r'^\d+[a-z]+$', time_value) is not None
+
+
+class NoSSHError(Exception):
+    pass
+
+
+def ssh_command():
+    """
+    Wrapper function for ssh command
+
+    When ssh between cluster nodes is blocked, core.no_ssh
+    should be set to 'yes', then this function will raise NoSSHError
+    """
+    if config.core.no_ssh:
+        raise NoSSHError(constants.NO_SSH_ERROR_MSG)
+    return "ssh"
+
+
+def load_cib_file_env():
+    if options.regression_tests or ServiceManager().service_is_active("pacemaker.service"):
+        return
+    cib_file = os.environ.setdefault('CIB_file', constants.CIB_RAW_FILE)
+    logger.warning("Cluster is not running, loading the CIB file from %s", cib_file)
+    if not os.path.exists(cib_file):
+        raise ValueError(f"Cannot find cib file: {cib_file}")
+
+
 # vim:ts=4:sw=4:et:
