@@ -91,7 +91,11 @@ def sudocall(cmd):
     cmd = add_sudo(cmd)
     if options.regression_tests:
         print(".EXT", cmd)
-    p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    p = subprocess.Popen(
+        cmd, shell=True,
+        stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+        env=os.environ,  # bsc#1205925
+    )
     try:
         outp, errp = p.communicate()
         p.wait()
@@ -130,7 +134,7 @@ def text2elem(text):
         return None
 
 
-def cibdump2elem(section=None):
+def cibdump2elem(section=None, no_side_effects=False):
     if section:
         cmd = "%s -o %s" % (cib_dump, section)
     else:
@@ -138,7 +142,7 @@ def cibdump2elem(section=None):
     rc, outp, errp = sudocall(cmd)
     if rc == 0:
         return text2elem(outp)
-    else:
+    elif not no_side_effects:
         logger.error("running %s: %s", cmd, errp)
     return None
 
