@@ -119,7 +119,7 @@ QDevice configuration:
   --qdevice-tie-breaker TIE_BREAKER
                         QNetd TIE_BREAKER (lowest/highest/valid_node_id,
                         default:lowest)
-  --qdevice-tls TLS     Whether using TLS on QDevice/QNetd (on/off/required,
+  --qdevice-tls TLS     Whether using TLS on QDevice (on/off/required,
                         default:on)
   --qdevice-heuristics COMMAND
                         COMMAND to run with absolute path. For multiple
@@ -332,7 +332,9 @@ optional arguments:
   -c [USER@]HOST, --cluster-node [USER@]HOST
                         An already-configured geo cluster or arbitrator
   -s DESC, --clusters DESC
-                        Geo cluster description (see geo-init for details)'''
+                        Geo cluster description (see geo-init for details)
+  --use-ssh-agent       Use an existing key from ssh-agent instead of creating
+                        new key pairs'''
 
 
 CRM_CLUSTER_GEO_INIT_ARBIT_H_OUTPUT = '''Initialize node as geo cluster arbitrator
@@ -351,3 +353,6 @@ optional arguments:
                         An already-configured geo cluster
   --use-ssh-agent       Use an existing key from ssh-agent instead of creating
                         new key pairs'''
+
+CRM_CONF_CONTENT_POSIONED = '''[core]
+hosts = alan@hanode1, claude@hanode2, john@hanode3'''
