@@ -169,13 +169,19 @@ def step_impl(context, msg):
     context.stderr = None
 
 
-@then('Expected regrex "{reg_str}" in stdout')
+@then('Expected regex "{reg_str}" in stdout')
 def step_impl(context, reg_str):
     res = re.search(reg_str, context.stdout)
     assert res is not None
     context.stdout = None
 
 
+@then('Expected regex "{reg_str}" in stderr')
+def step_impl(context, reg_str):
+    assert context.stderr is not None and re.search(reg_str, context.stderr)
+    context.stderr = None
+
+
 @then('Expected return code is "{num}"')
 def step_impl(context, num):
     assert context.return_code == int(num)
@@ -487,6 +493,13 @@ def step_impl(context, path, node):
     assert rc == 0
 
 
+@given('File "{path}" not exist on "{node}"')
+def step_impl(context, path, node):
+    cmd = '[ ! -f {} ]'.format(path)
+    rc, _, stderr = behave_agent.call(node, 1122, cmd, user='root')
+    assert rc == 0
+
+
 @then('File "{path}" not exist on "{node}"')
 def step_impl(context, path, node):
     cmd = '[ ! -f {} ]'.format(path)
@@ -573,3 +586,14 @@ def step_impl(context, target_file):
         return True
     else:
         return False
+
+@given('crm.conf poisoned on nodes [{nodes:str+}]')
+def step_impl(context, nodes):
+    for node in nodes:
+        rc, _, _ = behave_agent.call(
+            node, 1122,
+            f'''mkdir -p /root/.config/crm && cat > /root/.config/crm/crm.conf << EOF
+{const.CRM_CONF_CONTENT_POSIONED}
+EOF''',
+            user='root',
+        )
