@@ -75,20 +75,20 @@ class TestContext(unittest.TestCase):
     @mock.patch('crmsh.qdevice.QDevice')
     def test_initialize_qdevice(self, mock_qdevice):
         ctx = crmsh.bootstrap.Context()
-        ctx.qnetd_addr = "node3"
+        ctx.qnetd_addr_input = "node3"
         ctx.qdevice_port = 123
         ctx.stage = ""
         ctx.initialize_qdevice()
-        mock_qdevice.assert_called_once_with('node3', port=123, ssh_user=None, algo=None, tie_breaker=None, tls=None, cmds=None, mode=None, is_stage=False)
+        mock_qdevice.assert_called_once_with(qnetd_addr='node3', port=123, ssh_user=None, algo=None, tie_breaker=None, tls=None, cmds=None, mode=None, is_stage=False)
 
     @mock.patch('crmsh.qdevice.QDevice')
     def test_initialize_qdevice_with_user(self, mock_qdevice):
         ctx = crmsh.bootstrap.Context()
-        ctx.qnetd_addr = "alice@node3"
+        ctx.qnetd_addr_input = "alice@node3"
         ctx.qdevice_port = 123
         ctx.stage = ""
         ctx.initialize_qdevice()
-        mock_qdevice.assert_called_once_with('node3', port=123, ssh_user='alice', algo=None, tie_breaker=None, tls=None, cmds=None, mode=None, is_stage=False)
+        mock_qdevice.assert_called_once_with(qnetd_addr='node3', port=123, ssh_user='alice', algo=None, tie_breaker=None, tls=None, cmds=None, mode=None, is_stage=False)
 
     @mock.patch('crmsh.utils.fatal')
     def test_validate_sbd_option_error_together(self, mock_error):
@@ -443,15 +443,18 @@ class TestBootstrap(unittest.TestCase):
             mock.call(node_list, "systemctl daemon-reload"),
             ])
 
+    @mock.patch('crmsh.bootstrap.change_user_shell')
     @mock.patch('crmsh.bootstrap.configure_ssh_key')
     @mock.patch('crmsh.service_manager.ServiceManager.start_service')
-    def test_init_ssh(self, mock_start_service, mock_config_ssh):
+    def test_init_ssh(self, mock_start_service, mock_config_ssh, mock_change_user_shell):
         bootstrap._context = mock.Mock(current_user="alice", user_at_node_list=[], use_ssh_agent=False)
         bootstrap.init_ssh()
         mock_start_service.assert_called_once_with("sshd.service", enable=True)
         mock_config_ssh.assert_has_calls([
-            mock.call("alice")
-            ])
+            mock.call("alice"),
+            mock.call("hacluster"),
+        ])
+        mock_change_user_shell.assert_called_once_with("hacluster")
 
     @mock.patch('crmsh.userdir.gethomedir')
     def test_key_files(self, mock_gethome):
@@ -460,13 +463,6 @@ class TestBootstrap(unittest.TestCase):
         self.assertEqual(bootstrap.key_files("root"), expected_res)
         mock_gethome.assert_called_once_with("root")
 
-    @mock.patch('builtins.open')
-    def test_is_nologin(self, mock_open_file):
-        data = "hacluster:x:90:90:heartbeat processes:/var/lib/heartbeat/cores/hacluster:/sbin/nologin"
-        mock_open_file.return_value = mock.mock_open(read_data=data).return_value
-        assert bootstrap.is_nologin("hacluster") is not None
-        mock_open_file.assert_called_once_with("/etc/passwd")
-
     @mock.patch('crmsh.bootstrap.confirm')
     @mock.patch('logging.Logger.info')
     @mock.patch('crmsh.bootstrap.is_nologin')
@@ -515,12 +511,11 @@ class TestBootstrap(unittest.TestCase):
             ),
         ])
 
-    @mock.patch('crmsh.bootstrap.append_unique')
     @mock.patch('crmsh.sh.LocalShell.get_stdout_or_raise_error')
     @mock.patch('crmsh.utils.detect_file')
     @mock.patch('crmsh.bootstrap.key_files')
     @mock.patch('crmsh.bootstrap.change_user_shell')
-    def _test_configure_ssh_key(self, mock_change_shell, mock_key_files, mock_detect, mock_su, mock_append_unique):
+    def _test_configure_ssh_key(self, mock_change_shell, mock_key_files, mock_detect, mock_su):
         mock_key_files.return_value = {"private": "/test/.ssh/id_rsa", "public": "/test/.ssh/id_rsa.pub", "authorized": "/test/.ssh/authorized_keys"}
         mock_detect.side_effect = [True, True, False]
 
@@ -533,40 +528,19 @@ class TestBootstrap(unittest.TestCase):
             mock.call("/test/.ssh/id_rsa.pub"),
             mock.call("/test/.ssh/authorized_keys")
             ])
-        mock_append_unique.assert_called_once_with("/test/.ssh/id_rsa.pub", "/test/.ssh/authorized_keys", "test")
         mock_su.assert_called_once_with('test', 'touch /test/.ssh/authorized_keys')
 
     @mock.patch('crmsh.ssh_key.AuthorizedKeyManager.add')
     @mock.patch('crmsh.ssh_key.KeyFileManager.ensure_key_pair_exists_for_user')
-    def test_configure_ssh_key(self, mock_ensure_key_pair, mock_add):
+    @mock.patch('crmsh.bootstrap.change_user_shell')
+    def test_configure_ssh_key(self, mock_change_user_shell, mock_ensure_key_pair, mock_add):
         public_key = crmsh.ssh_key.InMemoryPublicKey('foo')
         mock_ensure_key_pair.return_value = (True, [public_key])
         bootstrap.configure_ssh_key('alice')
+        mock_change_user_shell.assert_called_once_with('alice')
         mock_ensure_key_pair.assert_called_once_with(None, 'alice')
         mock_add.assert_called_once_with(None, 'alice', public_key)
 
-    @mock.patch('crmsh.bootstrap.append_to_remote_file')
-    @mock.patch('crmsh.utils.check_file_content_included')
-    def test_append_unique_remote(self, mock_check, mock_append):
-        mock_check.return_value = False
-        bootstrap.append_unique("fromfile", "tofile", user="root", remote="node1", from_local=True)
-        mock_check.assert_called_once_with("fromfile", "tofile", remote="node1", source_local=True)
-        mock_append.assert_called_once_with("fromfile", "root", "node1", "tofile")
-
-    @mock.patch('crmsh.bootstrap.append')
-    @mock.patch('crmsh.utils.check_file_content_included')
-    def test_append_unique(self, mock_check, mock_append):
-        mock_check.return_value = False
-        bootstrap.append_unique("fromfile", "tofile")
-        mock_check.assert_called_once_with("fromfile", "tofile", remote=None, source_local=False)
-        mock_append.assert_called_once_with("fromfile", "tofile", remote=None)
-
-    @mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
-    def test_append_to_remote_file(self, mock_run):
-        bootstrap.append_to_remote_file("fromfile", "root", "node1", "tofile")
-        cmd = "cat fromfile | ssh {} root@node1 'cat >> tofile'".format(constants.SSH_OPTION)
-        mock_run.assert_called_once_with(cmd)
-
     @mock.patch('crmsh.utils.fatal')
     def test_join_ssh_no_seed_host(self, mock_error):
         mock_error.side_effect = ValueError
@@ -574,35 +548,49 @@ class TestBootstrap(unittest.TestCase):
             bootstrap.join_ssh(None, None)
         mock_error.assert_called_once_with("No existing IP/hostname specified (use -c option)")
 
+    @mock.patch('crmsh.bootstrap.detect_cluster_service_on_node')
+    @mock.patch('crmsh.bootstrap.get_node_canonical_hostname')
     @mock.patch('crmsh.bootstrap.swap_public_ssh_key_for_secondary_user')
     @mock.patch('crmsh.bootstrap.change_user_shell')
-    @mock.patch('crmsh.sh.LocalShell.get_stdout_or_raise_error')
+    @mock.patch('crmsh.sh.SSHShell')
     @mock.patch('crmsh.bootstrap.swap_public_ssh_key')
     @mock.patch('crmsh.utils.ssh_copy_id_no_raise')
     @mock.patch('crmsh.bootstrap.configure_ssh_key')
+    @mock.patch('crmsh.sh.LocalShell')
     @mock.patch('crmsh.service_manager.ServiceManager.start_service')
     def test_join_ssh(
             self,
-            mock_start_service, mock_config_ssh, mock_ssh_copy_id, mock_swap, mock_invoke, mock_change, mock_swap_2,
+            mock_start_service, mock_local_shell, mock_config_ssh, mock_ssh_copy_id, mock_swap,
+            mock_ssh_shell,
+            mock_change, mock_swap_2,
+            mock_get_node_cononical_hostname,
+            mock_detect_cluster_service_on_node
     ):
-        bootstrap._context = mock.Mock(current_user="bob", default_nic_list=["eth1"], use_ssh_agent=False)
-        mock_invoke.return_value = ''
+        bootstrap._context = mock.Mock(current_user="bob", default_nic="eth1", use_ssh_agent=False, stage=None)
         mock_swap.return_value = None
         mock_ssh_copy_id.return_value = 0
+        mock_subprocess_run_without_input = mock_ssh_shell.return_value.subprocess_run_without_input
+        mock_subprocess_run_without_input.return_value = mock.Mock(returncode=0)
+        mock_get_node_cononical_hostname.return_value='node1'
 
         bootstrap.join_ssh("node1", "alice")
 
         mock_start_service.assert_called_once_with("sshd.service", enable=True)
+        mock_local_shell: mock.MagicMock
+        mock_local_shell.assert_has_calls([
+            mock.call(additional_environ={'SSH_AUTH_SOCK': ''}),
+        ])
         mock_config_ssh.assert_has_calls([
                 mock.call("bob"),
                 mock.call("hacluster"),
             ])
-        mock_ssh_copy_id.assert_called_once_with("bob", "alice", "node1")
-        mock_swap.assert_called_once_with("node1", "bob", "alice", "bob", "alice", add=True)
-        mock_invoke.assert_called_once_with(
-            "bob",
-            "ssh {} alice@node1 sudo crm cluster init -i eth1 ssh_remote".format(constants.SSH_OPTION),
+        mock_ssh_copy_id.assert_called_once_with("bob", "alice", "node1", mock_local_shell.return_value)
+        mock_subprocess_run_without_input.assert_called_once_with(
+            'node1', 'alice', 'sudo true',
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
         )
+        mock_swap.assert_called_once_with("node1", "bob", "alice", "bob", "alice", add=True)
         mock_swap_2.assert_called_once()
         args, kwargs = mock_swap_2.call_args
         self.assertEqual(3, len(args))
@@ -647,8 +635,9 @@ class TestBootstrap(unittest.TestCase):
     @mock.patch('crmsh.bootstrap.swap_public_ssh_key')
     @mock.patch('crmsh.utils.ssh_copy_id_no_raise')
     @mock.patch('crmsh.bootstrap.configure_ssh_key')
+    @mock.patch('crmsh.sh.LocalShell')
     @mock.patch('crmsh.service_manager.ServiceManager.start_service')
-    def test_join_ssh_bad_credential(self, mock_start_service, mock_config_ssh, mock_ssh_copy_id, mock_swap, mock_invoke, mock_change):
+    def test_join_ssh_bad_credential(self, mock_start_service, mock_local_shell, mock_config_ssh, mock_ssh_copy_id, mock_swap, mock_invoke, mock_change):
         bootstrap._context = mock.Mock(current_user="bob", default_nic_list=["eth1"], use_ssh_agent=False)
         mock_invoke.return_value = ''
         mock_swap.return_value = None
@@ -658,10 +647,13 @@ class TestBootstrap(unittest.TestCase):
             bootstrap.join_ssh("node1", "alice")
 
         mock_start_service.assert_called_once_with("sshd.service", enable=True)
+        mock_local_shell.assert_has_calls([
+            mock.call(additional_environ={'SSH_AUTH_SOCK': ''}),
+        ])
         mock_config_ssh.assert_has_calls([
             mock.call("bob"),
         ])
-        mock_ssh_copy_id.assert_called_once_with("bob", "alice", "node1")
+        mock_ssh_copy_id.assert_called_once_with("bob", "alice", "node1", mock_local_shell.return_value)
         mock_swap.assert_not_called()
         mock_invoke.assert_not_called()
 
@@ -799,45 +791,6 @@ class TestBootstrap(unittest.TestCase):
             mock.call('node2', 'hacluster', 'hacluster', 'carol', 'bob', add=True)
             ])
 
-    @mock.patch('crmsh.userdir.getuser')
-    @mock.patch('crmsh.bootstrap.key_files')
-    @mock.patch('builtins.open')
-    @mock.patch('crmsh.bootstrap.append')
-    @mock.patch('os.path.join')
-    @mock.patch('os.path.exists')
-    def test_init_ssh_remote_no_sshkey(self, mock_exists, mock_join, mock_append, mock_open_file, mock_key_files, mock_getuser):
-        mock_getuser.return_value = "alice"
-        mock_key_files.return_value = {"private": "/home/alice/.ssh/id_rsa", "public": "/home/alice/.ssh/id_rsa.pub", "authorized": "/home/alice/.ssh/authorized_keys"}
-        mock_exists.side_effect = [False, True, False, False, False]
-        mock_join.side_effect = ["/home/alice/.ssh/id_rsa",
-                                 "/home/alice/.ssh/id_dsa",
-                                 "/home/alice/.ssh/id_ecdsa",
-                                 "/home/alice/.ssh/id_ed25519"]
-        mock_open_file.side_effect = [
-            mock.mock_open().return_value,
-            mock.mock_open(read_data="data1 data2").return_value,
-            mock.mock_open(read_data="data1111").return_value
-        ]
-
-        bootstrap.init_ssh_remote()
-
-        mock_getuser.assert_called_once_with()
-        mock_key_files.assert_called_once_with("alice")
-
-        mock_open_file.assert_has_calls([
-            mock.call("/home/alice/.ssh/authorized_keys", 'w'),
-            mock.call("/home/alice/.ssh/authorized_keys", "r+"),
-            mock.call("/home/alice/.ssh/id_rsa.pub")
-        ])
-        mock_exists.assert_has_calls([
-            mock.call("/home/alice/.ssh/authorized_keys"),
-            mock.call("/home/alice/.ssh/id_rsa"),
-            mock.call("/home/alice/.ssh/id_dsa"),
-            mock.call("/home/alice/.ssh/id_ecdsa"),
-            mock.call("/home/alice/.ssh/id_ed25519"),
-        ])
-        mock_append.assert_called_once_with("/home/alice/.ssh/id_rsa.pub", "/home/alice/.ssh/authorized_keys")
-
     @mock.patch('crmsh.sh.ClusterShell.get_rc_stdout_stderr_without_input')
     def test_get_node_canonical_hostname(self, mock_run):
         mock_run.return_value = (0, "Node1", None)
@@ -980,6 +933,75 @@ class TestBootstrap(unittest.TestCase):
         mock_interfaces_inst.get_default_nic_list_from_route.assert_called_once_with()
         mock_interfaces_inst.get_default_ip_list.assert_called_once_with()
 
+    @mock.patch('crmsh.utils.HostUserConfig')
+    @mock.patch('crmsh.ssh_key.AuthorizedKeyManager')
+    @mock.patch('crmsh.sh.cluster_shell')
+    @mock.patch('crmsh.ssh_key.InMemoryPublicKey')
+    @mock.patch('crmsh.bootstrap.remote_public_key_from')
+    @mock.patch('crmsh.utils.this_node')
+    @mock.patch('crmsh.utils.ssh_copy_id_no_raise')
+    @mock.patch('crmsh.utils.check_ssh_passwd_need')
+    @mock.patch('crmsh.bootstrap.UserOfHost.instance')
+    @mock.patch('crmsh.bootstrap._select_user_pair_for_ssh_for_secondary_components')
+    def test_setup_passwordless_ssh_for_qnetd_add_keys(self, mock_select, mock_user_of_host, mock_check_passwd, mock_ssh_copy_id, mock_this_node, mock_remote_public_key_from, mock_in_memory_public_key, mock_cluster_shell, mock_authorized_key_manager, mock_host_user_config_class):
+        bootstrap._context = mock.Mock(qnetd_addr_input="user@qnetd-node")
+        mock_select.side_effect = [("bob", "bob", "qnetd-node"), ("bob", "bob", "node2")]
+        mock_user_of_host_instance = mock.Mock()
+        mock_user_of_host.return_value = mock_user_of_host_instance
+        mock_user_of_host_instance.use_ssh_agent.return_value = False
+        mock_check_passwd.return_value = True
+        mock_ssh_copy_id.return_value = 0
+        mock_this_node.return_value = "node1"
+        mock_remote_public_key_from.return_value = "public_key"
+        mock_in_memory_public_key.return_value = "public_key"
+        mock_authorized_key_manager_instance = mock.Mock()
+        mock_authorized_key_manager.return_value = mock_authorized_key_manager_instance
+        mock_host_user_config_instance = mock.Mock()
+        mock_host_user_config_class.return_value = mock_host_user_config_instance
+
+        bootstrap._setup_passwordless_ssh_for_qnetd(["node1", "node2"])
+
+        mock_select.assert_has_calls([
+            mock.call(bootstrap._context.qnetd_addr_input),
+            mock.call('node2')
+            ])
+
+    @mock.patch('crmsh.utils.this_node')
+    @mock.patch('crmsh.utils.HostUserConfig')
+    @mock.patch('os.environ.get')
+    @mock.patch('crmsh.sh.SSHShell')
+    @mock.patch('crmsh.sh.LocalShell')
+    @mock.patch('crmsh.ssh_key.AuthorizedKeyManager')
+    @mock.patch('crmsh.ssh_key.AgentClient')
+    @mock.patch('logging.Logger.info')
+    @mock.patch('crmsh.bootstrap.UserOfHost.instance')
+    @mock.patch('crmsh.bootstrap._select_user_pair_for_ssh_for_secondary_components')
+    def test_setup_passwordless_ssh_for_qnetd_ssh_agent(self, mock_select, mock_user_of_host, mock_info, mock_agent, mock_authorized_key_manager, mock_local_shell, mock_ssh_shell, mock_get, mock_host_user_config_class, mock_this_node):
+        bootstrap._context = mock.Mock(qnetd_addr_input="user@qnetd-node")
+        mock_select.return_value = ("bob", "bob", "qnetd-node")
+        mock_user_of_host_instance = mock.Mock()
+        mock_user_of_host.return_value = mock_user_of_host_instance
+        mock_user_of_host_instance.use_ssh_agent.return_value = True
+        mock_agent_instance = mock.Mock()
+        mock_agent.return_value = mock_agent_instance
+        key_in_memory = mock.MagicMock(crmsh.ssh_key.InMemoryPublicKey)
+        mock_agent_instance.list.return_value = [key_in_memory]
+        mock_authorized_key_manager_instance = mock.Mock()
+        mock_authorized_key_manager.return_value = mock_authorized_key_manager_instance
+        mock_get.return_value = "/ssh-agent-path"
+        mock_local_shell_instance = mock.Mock()
+        mock_local_shell.return_value = mock_local_shell_instance
+        mock_ssh_shell_instance = mock.Mock()
+        mock_ssh_shell.return_value = mock_ssh_shell_instance
+        mock_this_node.return_value = "node1"
+        mock_host_uesr_config_instance = mock.Mock()
+        mock_host_user_config_class.return_value = mock_host_uesr_config_instance
+
+        bootstrap._setup_passwordless_ssh_for_qnetd(["node1", "node2"])
+
+        mock_info.assert_called_once_with("Adding public keys to authorized_keys for user root...")
+        mock_authorized_key_manager_instance.add.assert_called_once_with("qnetd-node", "bob", key_in_memory)
+
     @mock.patch('crmsh.service_manager.ServiceManager.disable_service')
     @mock.patch('logging.Logger.info')
     def test_init_qdevice_no_config(self, mock_status, mock_disable):
@@ -988,37 +1010,7 @@ class TestBootstrap(unittest.TestCase):
         mock_status.assert_not_called()
         mock_disable.assert_called_once_with("corosync-qdevice.service")
 
-    @mock.patch('crmsh.utils.HostUserConfig')
-    @mock.patch('crmsh.user_of_host.UserOfHost.instance')
-    @mock.patch('crmsh.utils.list_cluster_nodes')
-    @mock.patch('crmsh.utils.ssh_copy_id_no_raise')
-    @mock.patch('crmsh.bootstrap.configure_ssh_key')
-    @mock.patch('crmsh.utils.check_ssh_passwd_need')
-    @mock.patch('logging.Logger.info')
-    def test_init_qdevice_copy_ssh_key_failed(
-            self,
-            mock_status, mock_check_ssh_passwd_need,
-            mock_configure_ssh_key, mock_ssh_copy_id, mock_list_nodes, mock_user_of_host,
-            mock_host_user_config_class,
-    ):
-        mock_list_nodes.return_value = []
-        bootstrap._context = mock.Mock(qdevice_inst=self.qdevice_with_ip, current_user="bob")
-        mock_check_ssh_passwd_need.return_value = True
-        mock_ssh_copy_id.return_value = 255
-        mock_user_of_host.return_value = mock.MagicMock(crmsh.user_of_host.UserOfHost)
-        mock_user_of_host.return_value.user_pair_for_ssh.return_value = "bob", "bob"
-        mock_user_of_host.return_value.use_ssh_agent.return_value = False
-
-        with self.assertRaises(ValueError):
-            bootstrap.init_qdevice()
-
-        mock_status.assert_has_calls([
-            mock.call("Configure Qdevice/Qnetd:"),
-        ])
-        mock_check_ssh_passwd_need.assert_called_once_with("bob", "bob", "10.10.10.123")
-        mock_configure_ssh_key.assert_called_once_with('bob')
-        mock_ssh_copy_id.assert_called_once_with('bob', 'bob', '10.10.10.123')
-
+    @mock.patch('crmsh.bootstrap._select_user_pair_for_ssh_for_secondary_components')
     @mock.patch('crmsh.utils.HostUserConfig')
     @mock.patch('crmsh.user_of_host.UserOfHost.instance')
     @mock.patch('crmsh.utils.list_cluster_nodes')
@@ -1026,33 +1018,40 @@ class TestBootstrap(unittest.TestCase):
     @mock.patch('crmsh.utils.is_qdevice_configured')
     @mock.patch('crmsh.bootstrap.configure_ssh_key')
     @mock.patch('crmsh.utils.check_ssh_passwd_need')
+    @mock.patch('crmsh.sh.LocalShell')
     @mock.patch('logging.Logger.info')
     def test_init_qdevice_already_configured(
             self,
-            mock_status, mock_ssh, mock_configure_ssh_key,
+            mock_status, mock_local_shell, mock_ssh, mock_configure_ssh_key,
             mock_qdevice_configured, mock_confirm, mock_list_nodes, mock_user_of_host,
             mock_host_user_config_class,
+            mock_select_user_pair_for_ssh,
     ):
         mock_list_nodes.return_value = []
         bootstrap._context = mock.Mock(qdevice_inst=self.qdevice_with_ip, current_user="bob")
         mock_ssh.return_value = False
         mock_user_of_host.return_value = mock.MagicMock(crmsh.user_of_host.UserOfHost)
-        mock_user_of_host.return_value.user_pair_for_ssh.return_value = "bob", "bob"
         mock_user_of_host.return_value.use_ssh_agent.return_value = False
         mock_qdevice_configured.return_value = True
         mock_confirm.return_value = False
         self.qdevice_with_ip.start_qdevice_service = mock.Mock()
+        mock_select_user_pair_for_ssh.return_value = ("bob", "bob", 'qnetd-node')
 
         bootstrap.init_qdevice()
 
         mock_status.assert_called_once_with("Configure Qdevice/Qnetd:")
-        mock_ssh.assert_called_once_with("bob", "bob", "10.10.10.123")
+        mock_local_shell.assert_has_calls([
+            mock.call(additional_environ={'SSH_AUTH_SOCK': ''}),
+            mock.call(),
+        ])
+        mock_ssh.assert_called_once_with("bob", "bob", "qnetd-node", mock_local_shell.return_value)
         mock_configure_ssh_key.assert_not_called()
         mock_host_user_config_class.return_value.save_remote.assert_called_once_with(mock_list_nodes.return_value)
         mock_qdevice_configured.assert_called_once_with()
         mock_confirm.assert_called_once_with("Qdevice is already configured - overwrite?")
         self.qdevice_with_ip.start_qdevice_service.assert_called_once_with()
 
+    @mock.patch('crmsh.bootstrap._select_user_pair_for_ssh_for_secondary_components')
     @mock.patch('crmsh.utils.HostUserConfig')
     @mock.patch('crmsh.user_of_host.UserOfHost.instance')
     @mock.patch('crmsh.bootstrap.adjust_priority_fencing_delay')
@@ -1062,29 +1061,34 @@ class TestBootstrap(unittest.TestCase):
     @mock.patch('crmsh.utils.is_qdevice_configured')
     @mock.patch('crmsh.bootstrap.configure_ssh_key')
     @mock.patch('crmsh.utils.check_ssh_passwd_need')
+    @mock.patch('crmsh.sh.LocalShell')
     @mock.patch('logging.Logger.info')
-    def test_init_qdevice(self, mock_info, mock_ssh, mock_configure_ssh_key, mock_qdevice_configured,
+    def test_init_qdevice(self, mock_info, mock_local_shell, mock_ssh, mock_configure_ssh_key, mock_qdevice_configured,
                           mock_this_node, mock_list_nodes, mock_adjust_priority, mock_adjust_fence_delay,
-                          mock_user_of_host, mock_host_user_config_class):
+                          mock_user_of_host, mock_host_user_config_class, mock_select_user_pair_for_ssh):
         bootstrap._context = mock.Mock(qdevice_inst=self.qdevice_with_ip, current_user="bob")
         mock_this_node.return_value = "192.0.2.100"
         mock_list_nodes.return_value = []
         mock_ssh.return_value = False
         mock_user_of_host.return_value = mock.MagicMock(crmsh.user_of_host.UserOfHost)
-        mock_user_of_host.return_value.user_pair_for_ssh.return_value = "bob", "bob"
         mock_user_of_host.return_value.use_ssh_agent.return_value = False
         mock_qdevice_configured.return_value = False
         self.qdevice_with_ip.set_cluster_name = mock.Mock()
         self.qdevice_with_ip.valid_qnetd = mock.Mock()
         self.qdevice_with_ip.config_and_start_qdevice = mock.Mock()
+        mock_select_user_pair_for_ssh.return_value = ("bob", "bob", "qnetd-node")
 
         bootstrap.init_qdevice()
 
         mock_info.assert_called_once_with("Configure Qdevice/Qnetd:")
-        mock_ssh.assert_called_once_with("bob", "bob", "10.10.10.123")
+        mock_local_shell.assert_has_calls([
+            mock.call(additional_environ={'SSH_AUTH_SOCK': ''}),
+            mock.call(),
+        ])
+        mock_ssh.assert_called_once_with("bob", "bob", "qnetd-node", mock_local_shell.return_value)
         mock_host_user_config_class.return_value.add.assert_has_calls([
             mock.call('bob', '192.0.2.100'),
-            mock.call('bob', '10.10.10.123'),
+            mock.call('bob', 'qnetd-node'),
         ])
         mock_host_user_config_class.return_value.save_remote.assert_called_once_with(mock_list_nodes.return_value)
         mock_qdevice_configured.assert_called_once_with()
@@ -1160,15 +1164,14 @@ class TestBootstrap(unittest.TestCase):
         bootstrap.configure_qdevice_interactive()
         mock_confirm.assert_called_once_with("Do you want to configure QDevice?")
         mock_prompt.assert_has_calls([
-            mock.call("HOST or IP of the QNetd server to be used",
-                valid_func=qdevice.QDevice.check_qnetd_addr),
+            mock.call("HOST or IP of the QNetd server to be used"),
             mock.call("TCP PORT of QNetd server", default=5403,
                 valid_func=qdevice.QDevice.check_qdevice_port),
             mock.call("QNetd decision ALGORITHM (ffsplit/lms)", default="ffsplit",
                 valid_func=qdevice.QDevice.check_qdevice_algo),
             mock.call("QNetd TIE_BREAKER (lowest/highest/valid node id)", default="lowest",
                 valid_func=qdevice.QDevice.check_qdevice_tie_breaker),
-            mock.call("Whether using TLS on QDevice/QNetd (on/off/required)", default="on",
+            mock.call("Whether using TLS on QDevice (on/off/required)", default="on",
                 valid_func=qdevice.QDevice.check_qdevice_tls),
             mock.call("Heuristics COMMAND to run with absolute path; For multiple commands, use \";\" to separate",
                 valid_func=qdevice.QDevice.check_qdevice_heuristics,
@@ -1494,7 +1497,7 @@ class TestValidation(unittest.TestCase):
     @mock.patch('crmsh.bootstrap.Context')
     def test_bootstrap_remove_cluster_is_active(self, mock_context, mock_init, mock_active,
             mock_error):
-        mock_context_inst = mock.Mock()
+        mock_context_inst = mock.Mock(qdevice=False, cluster_node=None)
         mock_context.return_value = mock_context_inst
         mock_active.return_value = False
         mock_error.side_effect = SystemExit
@@ -1534,14 +1537,13 @@ class TestValidation(unittest.TestCase):
     def test_bootstrap_remove_qdevice_cluster_node(self, mock_context, mock_init, mock_active, mock_error):
         mock_context_inst = mock.Mock(qdevice=True, cluster_node="node1")
         mock_context.return_value = mock_context_inst
-        mock_active.return_value = True
         mock_error.side_effect = SystemExit
 
         with self.assertRaises(SystemExit):
             bootstrap.bootstrap_remove(mock_context_inst)
 
         mock_init.assert_called_once_with()
-        mock_active.assert_called_once_with("corosync.service")
+        mock_active.assert_not_called()
         mock_error.assert_called_once_with("Either remove node or qdevice")
 
     @mock.patch('crmsh.bootstrap.prompt_for_string')
@@ -1631,6 +1633,7 @@ class TestValidation(unittest.TestCase):
         mock_this_node.assert_called_once_with()
         mock_error.assert_called_once_with("Removing self requires --force")
 
+    @mock.patch('crmsh.bootstrap.bootstrap_finished')
     @mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
     @mock.patch('crmsh.bootstrap.remove_self')
     @mock.patch('crmsh.utils.this_node')
@@ -1642,7 +1645,7 @@ class TestValidation(unittest.TestCase):
     @mock.patch('crmsh.bootstrap.init')
     @mock.patch('crmsh.bootstrap.Context')
     def test_bootstrap_remove_self(self, mock_context, mock_init, mock_active,
-            mock_error, mock_qdevice, mock_hostname, mock_confirm, mock_this_node, mock_self, mock_run):
+                                   mock_error, mock_qdevice, mock_hostname, mock_confirm, mock_this_node, mock_self, mock_run, mock_finished):
         mock_context_inst = mock.Mock(cluster_node="node1", force=True, qdevice_rm_flag=None)
         mock_context.return_value = mock_context_inst
         mock_active.return_value = [True, True]
@@ -1750,7 +1753,7 @@ class TestValidation(unittest.TestCase):
 
         mock_list.assert_called_once_with(include_remote_nodes=False)
         mock_run.assert_called_once_with("node2", "crm cluster remove -y -c node1")
-        mock_error.assert_called_once_with("Failed to remove this node from node2")
+        mock_error.assert_called_once_with("Failed to remove this node from node2: err")
 
     @mock.patch('crmsh.utils.package_is_installed')
     @mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
@@ -1780,11 +1783,13 @@ class TestValidation(unittest.TestCase):
         mock_get_values.assert_called_once_with("nodelist.node.ring0_addr")
         mock_get_iplist.assert_called_once_with('node1')
 
+    @mock.patch('crmsh.utils.this_node')
     @mock.patch('crmsh.service_manager.ServiceManager.stop_service')
     @mock.patch('logging.Logger.info')
     @mock.patch('crmsh.service_manager.ServiceManager.service_is_active')
-    def test_stop_services(self, mock_active, mock_status, mock_stop):
+    def test_stop_services(self, mock_active, mock_status, mock_stop, mock_this_node):
         mock_active.side_effect = [True, True, True, True]
+        mock_this_node.side_effect = ['node1', 'node1', 'node1', 'node1']
         bootstrap.stop_services(bootstrap.SERVICES_STOP_LIST)
         mock_active.assert_has_calls([
             mock.call("corosync-qdevice.service", remote_addr=None),
@@ -1793,10 +1798,10 @@ class TestValidation(unittest.TestCase):
             mock.call("csync2.socket", remote_addr=None)
             ])
         mock_status.assert_has_calls([
-            mock.call('Stopping the %s%s', 'corosync-qdevice.service', ''),
-            mock.call('Stopping the %s%s', 'corosync.service', ''),
-            mock.call('Stopping the %s%s', 'hawk.service', ''),
-            mock.call('Stopping the %s%s', 'csync2.socket', '')
+            mock.call('Stopping the %s on %s', 'corosync-qdevice.service', 'node1'),
+            mock.call('Stopping the %s on %s', 'corosync.service', 'node1'),
+            mock.call('Stopping the %s on %s', 'hawk.service', 'node1'),
+            mock.call('Stopping the %s on %s', 'csync2.socket', 'node1')
             ])
         mock_stop.assert_has_calls([
             mock.call("corosync-qdevice.service", disable=True, remote_addr=None),
@@ -1822,7 +1827,7 @@ class TestValidation(unittest.TestCase):
             bootstrap.remove_node_from_cluster('node1')
 
         mock_get_ip.assert_called_once_with('node1')
-        mock_status.assert_called_once_with("Removing the node node1")
+        mock_status.assert_called_once_with("Removing node %s from CIB", "node1")
         mock_stop.assert_called_once_with(bootstrap.SERVICES_STOP_LIST, remote_addr="node1")
         mock_invoke.assert_not_called()
         mock_call_delnode.assert_called_once_with("node1")
@@ -1847,7 +1852,7 @@ class TestValidation(unittest.TestCase):
             bootstrap.remove_node_from_cluster('node1')
 
         mock_get_ip.assert_called_once_with('node1')
-        mock_status.assert_called_once_with("Removing the node node1")
+        mock_status.assert_called_once_with("Removing node %s from CIB", "node1")
         mock_stop.assert_called_once_with(bootstrap.SERVICES_STOP_LIST, remote_addr="node1")
         mock_invoke.assert_not_called()
         mock_call_delnode.assert_called_once_with("node1")
@@ -1886,7 +1891,7 @@ class TestValidation(unittest.TestCase):
 
         mock_get_ip.assert_called_once_with('node1')
         mock_status.assert_has_calls([
-            mock.call("Removing the node node1"),
+            mock.call("Removing node %s from CIB", "node1"),
             mock.call("Propagating configuration changes across the remaining nodes")
             ])
         mock_stop.assert_called_once_with(bootstrap.SERVICES_STOP_LIST, remote_addr="node1")
