@@ -47,8 +47,12 @@ def test_query_status_exception():
     assert str(err.value) == "Wrong type \"test\" to query status"
 
 
+@mock.patch('crmsh.sh.cluster_shell')
 @mock.patch('crmsh.corosync.query_ring_status')
-def test_query_status(mock_ring_status):
+def test_query_status(mock_ring_status, mock_cluster_shell):
+    mock_cluster_shell_inst = mock.Mock()
+    mock_cluster_shell.return_value = mock_cluster_shell_inst
+    mock_cluster_shell_inst.get_stdout_or_raise_error.return_value = "data"
     corosync.query_status("ring")
     mock_ring_status.assert_called_once_with()
 
@@ -62,30 +66,40 @@ def test_query_qdevice_status_exception(mock_configured):
     mock_configured.assert_called_once_with()
 
 
-@mock.patch('crmsh.utils.print_cluster_nodes')
 @mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
 @mock.patch('crmsh.utils.is_qdevice_configured')
-def test_query_qdevice_status(mock_configured, mock_run, mock_print):
+def test_query_qdevice_status(mock_configured, mock_run):
     mock_configured.return_value = True
     corosync.query_qdevice_status()
     mock_run.assert_called_once_with("corosync-qdevice-tool -sv")
-    mock_print.assert_called_once_with()
 
 
+@mock.patch('crmsh.sh.cluster_shell')
 @mock.patch("crmsh.corosync.query_ring_status")
-def test_query_status_ring(mock_ring_status):
+def test_query_status_ring(mock_ring_status, mock_cluster_shell):
+    mock_cluster_shell_inst = mock.Mock()
+    mock_cluster_shell.return_value = mock_cluster_shell_inst
+    mock_cluster_shell_inst.get_stdout_or_raise_error.return_value = "data"
     corosync.query_status("ring")
     mock_ring_status.assert_called_once_with()
 
 
+@mock.patch('crmsh.sh.cluster_shell')
 @mock.patch("crmsh.corosync.query_quorum_status")
-def test_query_status_quorum(mock_quorum_status):
+def test_query_status_quorum(mock_quorum_status, mock_cluster_shell):
+    mock_cluster_shell_inst = mock.Mock()
+    mock_cluster_shell.return_value = mock_cluster_shell_inst
+    mock_cluster_shell_inst.get_stdout_or_raise_error.return_value = "data"
     corosync.query_status("quorum")
     mock_quorum_status.assert_called_once_with()
 
 
+@mock.patch('crmsh.sh.cluster_shell')
 @mock.patch("crmsh.corosync.query_qnetd_status")
-def test_query_status_qnetd(mock_qnetd_status):
+def test_query_status_qnetd(mock_qnetd_status, mock_cluster_shell):
+    mock_cluster_shell_inst = mock.Mock()
+    mock_cluster_shell.return_value = mock_cluster_shell_inst
+    mock_cluster_shell_inst.get_stdout_or_raise_error.return_value = "data"
     corosync.query_status("qnetd")
     mock_qnetd_status.assert_called_once_with()
 
@@ -112,33 +126,27 @@ def test_query_ring_status(mock_run):
     mock_run.assert_called_once_with("corosync-cfgtool -s")
 
 
-@mock.patch("crmsh.utils.print_cluster_nodes")
 @mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
-def test_query_quorum_status_except(mock_run, mock_print_nodes):
+def test_query_quorum_status_except(mock_run):
     mock_run.return_value = (1, None, "error")
     with pytest.raises(ValueError) as err:
         corosync.query_quorum_status()
     assert str(err.value) == "error"
     mock_run.assert_called_once_with("corosync-quorumtool -s")
-    mock_print_nodes.assert_called_once_with()
 
 
-@mock.patch("crmsh.utils.print_cluster_nodes")
 @mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
-def test_query_quorum_status(mock_run, mock_print_nodes):
+def test_query_quorum_status(mock_run):
     mock_run.return_value = (0, "data", None)
     corosync.query_quorum_status()
     mock_run.assert_called_once_with("corosync-quorumtool -s")
-    mock_print_nodes.assert_called_once_with()
 
 
-@mock.patch("crmsh.utils.print_cluster_nodes")
 @mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
-def test_query_quorum_status_no_quorum(mock_run, mock_print_nodes):
+def test_query_quorum_status_no_quorum(mock_run):
     mock_run.return_value = (2, "no quorum", None)
     corosync.query_quorum_status()
     mock_run.assert_called_once_with("corosync-quorumtool -s")
-    mock_print_nodes.assert_called_once_with()
 
 
 @mock.patch("crmsh.utils.is_qdevice_configured")
@@ -179,18 +187,14 @@ def test_query_qnetd_status_no_host(mock_qdevice_configured, mock_get_value):
 
 @mock.patch('crmsh.utils.user_pair_for_ssh')
 @mock.patch("crmsh.parallax.parallax_call")
-@mock.patch("crmsh.utils.ssh_copy_id")
-@mock.patch('crmsh.bootstrap.configure_ssh_key')
-@mock.patch("crmsh.utils.check_ssh_passwd_need")
 @mock.patch("crmsh.corosync.get_value")
 @mock.patch("crmsh.utils.is_qdevice_configured")
 def test_query_qnetd_status_copy_id_failed(mock_qdevice_configured,
-        mock_get_value, mock_check_passwd, mock_config_ssh_key, mock_ssh_copy_id, mock_parallax_call, mock_user_pair_for_ssh):
+        mock_get_value, mock_parallax_call, mock_user_pair_for_ssh):
     mock_user_pair_for_ssh.return_value = "alice", "root"
     mock_parallax_call.side_effect = ValueError("Failed on 10.10.10.123: foo")
     mock_qdevice_configured.return_value = True
     mock_get_value.side_effect = ["hacluster", "10.10.10.123"]
-    mock_check_passwd.return_value = True
     with pytest.raises(ValueError) as err:
         corosync.query_qnetd_status()
     assert err.value.args[0] == "Failed on 10.10.10.123: foo"
@@ -199,26 +203,17 @@ def test_query_qnetd_status_copy_id_failed(mock_qdevice_configured,
         mock.call("totem.cluster_name"),
         mock.call("quorum.device.net.host")
         ])
-    mock_check_passwd.assert_called_once_with("alice", "root", "10.10.10.123")
-    mock_config_ssh_key.assert_called_once_with('alice')
-    mock_ssh_copy_id.assert_called_once_with('alice', 'root', '10.10.10.123')
 
 
 @mock.patch('crmsh.utils.user_pair_for_ssh')
-@mock.patch("crmsh.utils.print_cluster_nodes")
 @mock.patch("crmsh.parallax.parallax_call")
-@mock.patch("crmsh.utils.ssh_copy_id")
-@mock.patch('crmsh.bootstrap.configure_ssh_key')
-@mock.patch("crmsh.utils.check_ssh_passwd_need")
 @mock.patch("crmsh.corosync.get_value")
 @mock.patch("crmsh.utils.is_qdevice_configured")
 def test_query_qnetd_status_copy(mock_qdevice_configured, mock_get_value,
-        mock_check_passwd, mock_config_ssh_key, mock_ssh_copy_id, mock_parallax_call, mock_print_nodes,
-        mock_user_pair_for_ssh):
+        mock_parallax_call, mock_user_pair_for_ssh):
     mock_user_pair_for_ssh.return_value = "alice", "root"
     mock_qdevice_configured.return_value = True
     mock_get_value.side_effect = ["hacluster", "10.10.10.123"]
-    mock_check_passwd.return_value = True
     mock_parallax_call.return_value = [("node1", (0, "data", None)), ]
 
     corosync.query_qnetd_status()
@@ -228,11 +223,7 @@ def test_query_qnetd_status_copy(mock_qdevice_configured, mock_get_value,
         mock.call("totem.cluster_name"),
         mock.call("quorum.device.net.host")
         ])
-    mock_check_passwd.assert_called_once_with("alice", "root", "10.10.10.123")
-    mock_config_ssh_key.assert_called_once_with('alice')
-    mock_ssh_copy_id.assert_called_once_with('alice', 'root', '10.10.10.123')
     mock_parallax_call.assert_called_once_with(["10.10.10.123"], "corosync-qnetd-tool -lv -c hacluster")
-    mock_print_nodes.assert_called_once_with()
 
 
 @mock.patch('crmsh.utils.get_nodeinfo_from_cmaptool')
