@@ -48,7 +48,7 @@ class TestLock(unittest.TestCase):
         Global tearDown.
         """
 
-    @mock.patch('crmsh.utils.get_stdout_stderr')
+    @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
     def test_run(self, mock_run):
         mock_run.return_value = (0, "output data", None)
         rc, out, err = self.local_inst._run("test_cmd")
@@ -59,28 +59,28 @@ class TestLock(unittest.TestCase):
         mock_run.return_value = (1, None, None)
         rc = self.local_inst._create_lock_dir()
         self.assertEqual(rc, False)
-        mock_run.assert_called_once_with("mkdir {}".format(lock.Lock.LOCK_DIR_NON_PRIVILEGED))
+        mock_run.assert_called_once_with("mkdir {}".format(lock.Lock.LOCK_DIR_DEFAULT))
 
     @mock.patch('crmsh.lock.Lock._run')
     def test_create_lock_dir(self, mock_run):
         mock_run.return_value = (0, None, None)
         rc = self.local_inst._create_lock_dir()
         self.assertEqual(rc, True)
-        mock_run.assert_called_once_with("mkdir {}".format(lock.Lock.LOCK_DIR_NON_PRIVILEGED))
+        mock_run.assert_called_once_with("mkdir {}".format(lock.Lock.LOCK_DIR_DEFAULT))
 
     @mock.patch('crmsh.lock.Lock._create_lock_dir')
     def test_lock_or_fail(self, mock_create):
         mock_create.return_value = False
         with self.assertRaises(lock.ClaimLockError) as err:
             self.local_inst._lock_or_fail()
-        self.assertEqual("Failed to claim lock (the lock directory exists at {})".format(lock.Lock.LOCK_DIR_NON_PRIVILEGED), str(err.exception))
+        self.assertEqual("Failed to claim lock (the lock directory exists at {})".format(lock.Lock.LOCK_DIR_DEFAULT), str(err.exception))
         mock_create.assert_called_once_with()
 
     @mock.patch('crmsh.lock.Lock._run')
     def test_unlock(self, mock_run):
         self.local_inst.lock_owner = True
         self.local_inst._unlock()
-        mock_run.assert_called_once_with("rm -rf {}".format(lock.Lock.LOCK_DIR_NON_PRIVILEGED))
+        mock_run.assert_called_once_with("rm -rf {}".format(lock.Lock.LOCK_DIR_DEFAULT))
 
     @mock.patch('crmsh.lock.Lock._unlock')
     @mock.patch('crmsh.lock.Lock._lock_or_fail')
@@ -132,20 +132,20 @@ class TestRemoteLock(unittest.TestCase):
         Global tearDown.
         """
 
-    @mock.patch('crmsh.utils.run_cmd_on_remote')
+    @mock.patch('crmsh.sh.ClusterShell.get_rc_stdout_stderr_without_input')
     def test_run_ssh_error(self, mock_run):
         mock_run.return_value = (255, None, "ssh error")
         with self.assertRaises(lock.SSHError) as err:
             self.lock_inst._run("cmd")
         self.assertEqual("ssh error", str(err.exception))
-        mock_run.assert_called_once_with("cmd", "node1")
+        mock_run.assert_called_once_with("node1", "cmd")
 
-    @mock.patch('crmsh.utils.run_cmd_on_remote')
+    @mock.patch('crmsh.sh.ClusterShell.get_rc_stdout_stderr_without_input')
     def test_run(self, mock_run):
         mock_run.return_value = (0, None, None)
         res = self.lock_inst._run("cmd")
         self.assertEqual(res, mock_run.return_value)
-        mock_run.assert_called_once_with("cmd", "node1")
+        mock_run.assert_called_once_with("node1", "cmd")
 
     def test_lock_timeout_error_format(self):
         config.core.lock_timeout = "pwd"
@@ -211,7 +211,7 @@ class TestRemoteLock(unittest.TestCase):
 
         with self.assertRaises(lock.ClaimLockError) as err:
             self.lock_inst._lock_or_wait()
-        self.assertEqual("Timed out after 120 seconds. Cannot continue since the lock directory exists at the node (node1:{})".format(lock.Lock.LOCK_DIR_NON_PRIVILEGED), str(err.exception))
+        self.assertEqual("Timed out after 120 seconds. Cannot continue since the lock directory exists at the node (node1:{})".format(lock.Lock.LOCK_DIR_DEFAULT), str(err.exception))
 
         mock_time.assert_has_calls([ mock.call(), mock.call()])
         mock_time_out.assert_has_calls([mock.call(), mock.call(), mock.call()])
