@@ -27,13 +27,6 @@ def setup_function():
     imp.reload(utils)
 
 
-@mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
-def test_print_cluster_nodes(mock_run):
-    mock_run.return_value = (0, "data", None)
-    utils.print_cluster_nodes()
-    mock_run.assert_called_once_with("crm_node -l")
-
-
 @mock.patch("crmsh.sh.ShellUtils.get_stdout")
 def test_package_is_installed_local(mock_run):
     mock_run.return_value = (0, None)
@@ -42,36 +35,6 @@ def test_package_is_installed_local(mock_run):
     mock_run.assert_called_once_with("rpm -q --quiet crmsh")
 
 
-@mock.patch('crmsh.utils.detect_file')
-def test_check_file_content_included_target_not_exist(mock_detect):
-    mock_detect.side_effect = [True, False]
-    res = utils.check_file_content_included("file1", "file2")
-    assert res is False
-    mock_detect.assert_has_calls([
-        mock.call("file1", remote=None),
-        mock.call("file2", remote=None)
-        ])
-
-
-@mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
-@mock.patch('crmsh.utils.detect_file')
-def test_check_file_content_included(mock_detect, mock_run):
-    mock_detect.side_effect = [True, True]
-    mock_run.side_effect = ["data data", "data"]
-
-    res = utils.check_file_content_included("file1", "file2")
-    assert res is True
-
-    mock_detect.assert_has_calls([
-        mock.call("file1", remote=None),
-        mock.call("file2", remote=None)
-        ])
-    mock_run.assert_has_calls([
-        mock.call("cat file2", host=None),
-        mock.call("cat file1", host=None)
-        ])
-
-
 @mock.patch('re.search')
 @mock.patch('crmsh.sh.ShellUtils.get_stdout')
 def test_get_nodeid_from_name_run_None1(mock_get_stdout, mock_re_search):
@@ -116,7 +79,7 @@ def test_check_ssh_passwd_need(mock_run):
     assert res is True
     mock_run.assert_called_once_with(
         "bob",
-        " ssh -o StrictHostKeyChecking=no -o EscapeChar=none -o ConnectTimeout=15 -T -o Batchmode=yes alice@node1 true",
+        "ssh -o StrictHostKeyChecking=no -o EscapeChar=none -o ConnectTimeout=15 -T -o Batchmode=yes alice@node1 true",
     )
 
 
@@ -309,39 +272,37 @@ def test_sysconfig_set_bsc1145823():
     sc = utils.parse_sysconfig(fname)
     assert (sc.get("age") == "100")
 
-@mock.patch("crmsh.utils.IP.is_ipv6")
+@mock.patch("socket.getaddrinfo")
 @mock.patch("socket.socket")
 @mock.patch("crmsh.utils.closing")
-def test_check_port_open_false(mock_closing, mock_socket, mock_is_ipv6):
-    mock_is_ipv6.return_value = False
+def test_check_port_open_false(mock_closing, mock_socket, mock_getaddrinfo):
     sock_inst = mock.Mock()
     mock_socket.return_value = sock_inst
     mock_closing.return_value.__enter__.return_value = sock_inst
     sock_inst.connect_ex.return_value = 1
+    mock_getaddrinfo.return_value = [(socket.AF_INET, socket.SOCK_STREAM, 6, "", ("127.0.0.1", 22))]
 
-    assert utils.check_port_open("10.10.10.1", 22) is False
+    assert utils.check_port_open("localhost", 22) is False
 
-    mock_is_ipv6.assert_called_once_with("10.10.10.1")
-    mock_socket.assert_called_once_with(socket.AF_INET, socket.SOCK_STREAM)
+    mock_socket.assert_called_once_with(socket.AF_INET, socket.SOCK_STREAM, 6)
     mock_closing.assert_called_once_with(sock_inst)
-    sock_inst.connect_ex.assert_called_once_with(("10.10.10.1", 22))
+    sock_inst.connect_ex.assert_called_once_with(("127.0.0.1", 22))
 
-@mock.patch("crmsh.utils.IP.is_ipv6")
+@mock.patch("socket.getaddrinfo")
 @mock.patch("socket.socket")
 @mock.patch("crmsh.utils.closing")
-def test_check_port_open_true(mock_closing, mock_socket, mock_is_ipv6):
-    mock_is_ipv6.return_value = True
+def test_check_port_open_true(mock_closing, mock_socket, mock_getaddrinfo):
     sock_inst = mock.Mock()
     mock_socket.return_value = sock_inst
     mock_closing.return_value.__enter__.return_value = sock_inst
     sock_inst.connect_ex.return_value = 0
+    mock_getaddrinfo.return_value = [(socket.AF_INET, socket.SOCK_STREAM, 6, "", ("127.0.0.1", 22))]
 
-    assert utils.check_port_open("2001:db8:10::7", 22) is True
+    assert utils.check_port_open("localhost", 22) is True
 
-    mock_is_ipv6.assert_called_once_with("2001:db8:10::7")
-    mock_socket.assert_called_once_with(socket.AF_INET6, socket.SOCK_STREAM)
+    mock_socket.assert_called_once_with(socket.AF_INET, socket.SOCK_STREAM, 6)
     mock_closing.assert_called_once_with(sock_inst)
-    sock_inst.connect_ex.assert_called_once_with(("2001:db8:10::7", 22))
+    sock_inst.connect_ex.assert_called_once_with(("127.0.0.1", 22))
 
 def test_valid_port():
     assert utils.valid_port(1) is False
@@ -894,15 +855,6 @@ def test_get_iplist_from_name(mock_get_nodeid, mock_get_nodeinfo):
     mock_get_nodeinfo.assert_called_once_with()
 
 
-@mock.patch("crmsh.sh.ShellUtils.get_stdout_stderr")
-def test_ping_node(mock_run):
-    mock_run.return_value = (1, None, "error data")
-    with pytest.raises(ValueError) as err:
-        utils.ping_node("node_unreachable")
-    assert str(err.value) == 'host "node_unreachable" is unreachable: error data'
-    mock_run.assert_called_once_with("ping -c 1 node_unreachable")
-
-
 def test_calculate_quorate_status():
     assert utils.calculate_quorate_status(3, 2) is True
     assert utils.calculate_quorate_status(3, 1) is False
@@ -1136,13 +1088,13 @@ def test_is_block_device(mock_stat, mock_isblk):
     mock_isblk.assert_called_once_with(12345)
 
 
-@mock.patch('crmsh.utils.ping_node')
+@mock.patch('crmsh.utils.node_reachable_check')
 @mock.patch('crmsh.sh.ClusterShell.get_stdout_or_raise_error')
-def test_check_all_nodes_reachable(mock_run, mock_ping):
+def test_check_all_nodes_reachable(mock_run, mock_reachable):
     mock_run.return_value = "1084783297 15sp2-1 member"
     utils.check_all_nodes_reachable()
     mock_run.assert_called_once_with("crm_node -l")
-    mock_ping.assert_called_once_with("15sp2-1")
+    mock_reachable.assert_called_once_with("15sp2-1")
 
 
 @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
@@ -1243,17 +1195,6 @@ def test_list_cluster_nodes_none(mock_run, mock_etree):
     mock_etree.assert_called_once_with("data")
 
 
-@mock.patch('crmsh.utils.etree.fromstring')
-@mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
-def test_list_cluster_nodes_none_no_reg(mock_run, mock_etree):
-    mock_run.return_value = (0, "data", None)
-    mock_etree.return_value = None
-    res = utils.list_cluster_nodes(no_reg=True)
-    assert res is None
-    mock_run.assert_called_once_with(constants.CIB_QUERY, no_reg=True)
-    mock_etree.assert_called_once_with("data")
-
-
 @mock.patch('os.path.isfile')
 @mock.patch('os.getenv')
 @mock.patch('crmsh.sh.ShellUtils.get_stdout_stderr')
@@ -1293,7 +1234,7 @@ def test_list_cluster_nodes(mock_run, mock_env, mock_isfile, mock_file2elem):
     mock_file2elem.assert_called_once_with(constants.CIB_RAW_FILE)
     mock_cib_inst.xpath.assert_has_calls([
         mock.call(constants.XML_NODE_PATH),
-        mock.call("//primitive[@id='node1']/instance_attributes/nvpair[@name='server']")
+        mock.call("//primitive[@provider='pacemaker' and @type='remote']/instance_attributes/nvpair[@name='server' and @value='node1']")
         ])
 
 
@@ -1315,7 +1256,7 @@ def test_set_property(mock_get, mock_run, mock_warn):
     mock_get.return_value = "start"
     utils.set_property("no-quorum-policy", "stop")
     mock_run.assert_called_once_with("crm configure property no-quorum-policy=stop")
-    mock_warn.assert_called_once_with('"no-quorum-policy" in crm_config is set to stop, it was start')
+    mock_warn.assert_called_once_with('"%s" in %s is set to %s, it was %s', 'no-quorum-policy', 'crm_config', 'stop', 'start')
 
 
 @mock.patch('crmsh.utils.get_property')
@@ -1446,15 +1387,16 @@ def test_has_sudo_access(mock_run):
     mock_run.assert_called_once_with("sudo -S -k -n id -u")
 
 
-@mock.patch('grp.getgrgid')
+@mock.patch('grp.getgrnam')
+@mock.patch('os.getegid')
 @mock.patch('os.getgroups')
-def test_in_haclient(mock_group, mock_getgrgid):
-    mock_group.return_value = [90, 100]
-    mock_getgrgid_inst1 = mock.Mock(gr_name=constants.HA_GROUP)
-    mock_getgrgid_inst2 = mock.Mock(gr_name="other")
-    mock_getgrgid.side_effect = [mock_getgrgid_inst1, mock_getgrgid_inst2]
+def test_in_haclient(mock_getgroups, mock_getegid, mock_getgrnam):
+    mock_getgroups.return_value = [90]
+    mock_getegid.return_value = 90
+    mock_getgrnam_inst = mock.Mock(gr_gid=90)
+    mock_getgrnam.return_value = mock_getgrnam_inst
     assert utils.in_haclient() is True
-    mock_group.assert_called_once_with()
+    mock_getgrnam.assert_called_once_with(constants.HA_GROUP)
 
 
 @mock.patch('crmsh.utils.in_haclient')
@@ -1498,7 +1440,7 @@ def test_check_user_access_acl(mock_user, mock_in, mock_sudo, mock_error):
     mock_sudo.return_value = False
     with pytest.raises(utils.TerminateSubCommand) as err:
         utils.check_user_access('ra')
-    mock_error.assert_called_once_with('This command needs higher privilege.\nOption 1) Please consider to add "user" as sudoer. For example:\n  sudo bash -c \'echo "user ALL=(ALL) NOPASSWD:ALL" > /etc/sudoers.d/user\'\nOption 2) Add "user" to the haclient group. For example:\n  sudo usermod -g haclient user')
+    mock_error.assert_called_once_with('Operation is denied. The current user lacks the necessary privilege.')
 
 
 @mock.patch('logging.Logger.error')
@@ -1511,4 +1453,4 @@ def test_check_user_access_cluster(mock_user, mock_in, mock_sudo, mock_error):
     mock_sudo.return_value = False
     with pytest.raises(utils.TerminateSubCommand) as err:
         utils.check_user_access('cluster')
-    mock_error.assert_called_once_with('Please run this command starting with "sudo".\nCurrently, this command needs to use sudo to escalate itself as root.\nPlease consider to add "user" as sudoer. For example:\n  sudo bash -c \'echo "user ALL=(ALL) NOPASSWD:ALL" > /etc/sudoers.d/user\'')
+    mock_error.assert_called_once_with('Operation is denied. The current user lacks the necessary privilege.')
